@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -29,12 +29,12 @@
  *
  *********************************************************/
 
-/**********************************************************
- * Filename: cddb_tab.c
+/*!********************************************************
+ * \file 
+ * The freedb tab
  *
  * this file is used for the cddb tab 
  *   (for searching on freedb)
- *
  *********************************************************/
 
 #include <stdlib.h>
@@ -51,6 +51,7 @@
 #include "tree_tab.h"
 #include "preferences_tab.h"
 #include "utilities.h"
+#include "mp3splt-gtk.h"
 
 //handle box for detaching window
 GtkWidget *freedb_handle_box;
@@ -91,7 +92,7 @@ extern gchar current_description[255];
 extern GtkWidget *output_entry;
 extern gint debug_is_active;
 
-//add a row to the table
+//!add a row to the table
 void add_freedb_row(gchar *album_name, 
                     gint album_id,
                     gint *revisions,
@@ -138,7 +139,7 @@ void add_freedb_row(gchar *album_name,
   g_free(number);
 }
 
-//creates the model for the freedb tree
+//!creates the model for the freedb tree
 GtkTreeModel *create_freedb_model()
 {
   GtkTreeStore *model;
@@ -149,7 +150,7 @@ GtkTreeModel *create_freedb_model()
   return GTK_TREE_MODEL (model);
 }
 
-//creates the freedb tree
+//!creates the freedb tree
 GtkTreeView *create_freedb_tree()
 {
   GtkTreeView *tree_view;
@@ -163,7 +164,7 @@ GtkTreeView *create_freedb_tree()
   return tree_view;
 }
 
-//creates freedb columns
+//!creates freedb columns
 void create_freedb_columns (GtkTreeView *tree_view)
 {
   //cells renderer
@@ -214,7 +215,7 @@ void create_freedb_columns (GtkTreeView *tree_view)
                                       TRUE);
 }
 
-//when closing the new window after detaching
+//!when closing the new window after detaching
 void close_freedb_popup_window_event( GtkWidget *window,
                                       gpointer data )
 {
@@ -228,7 +229,7 @@ void close_freedb_popup_window_event( GtkWidget *window,
   gtk_widget_destroy(window);
 }
 
-//when we detach the handle
+//!when we detach the handle
 void handle_freedb_detached_event (GtkHandleBox *handlebox,
                                  GtkWidget *widget,
                                  gpointer data)
@@ -245,7 +246,7 @@ void handle_freedb_detached_event (GtkHandleBox *handlebox,
   gtk_widget_show(GTK_WIDGET(window));
 }
 
-//freedb selection has changed
+//!freedb selection has changed
 void freedb_selection_changed(GtkTreeSelection *selection,
                               gpointer data)
 {
@@ -275,7 +276,7 @@ void freedb_selection_changed(GtkTreeSelection *selection,
     }
 }
 
-//removes all rows from the freedb table
+//!removes all rows from the freedb table
 void remove_all_freedb_rows ()
 {
   GtkTreeIter iter;
@@ -293,26 +294,26 @@ void remove_all_freedb_rows ()
     }
 }
 
-//search the freedb.org
+//!search the freedb.org
 gpointer freedb_search(gpointer data)
 {
-  gdk_threads_enter();
+  enter_threads();
  
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_add_button), FALSE);
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_search_button), FALSE);
-  gtk_entry_set_editable(GTK_ENTRY(freedb_entry), FALSE);
+  gtk_editable_set_editable(GTK_EDITABLE(freedb_entry), FALSE);
  
   put_status_message(_("please wait... contacting tracktype.org"));
  
   const gchar *freedb_search = gtk_entry_get_text(GTK_ENTRY(freedb_entry));
   
-  gdk_threads_leave();
+  exit_threads();
   
   gint err = SPLT_OK;
   search_results = mp3splt_get_freedb_search(the_state, freedb_search, &err,
       SPLT_FREEDB_SEARCH_TYPE_CDDB_CGI, "\0",-1);
  
-  gdk_threads_enter();
+  enter_threads();
 
   print_status_bar_confirmation(err);
  
@@ -352,39 +353,44 @@ gpointer freedb_search(gpointer data)
   }
  
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_search_button), TRUE);
-  gtk_entry_set_editable(GTK_ENTRY(freedb_entry), TRUE);
+  gtk_editable_set_editable(GTK_EDITABLE(freedb_entry), TRUE);
  
-  gdk_threads_leave();
+  exit_threads();
 
   return NULL;
 }
 
+//! Start a thread for the freedb search
 void freedb_search_start_thread()
 {
   mp3splt_set_int_option(the_state, SPLT_OPT_DEBUG_MODE, debug_is_active);
-  g_thread_create(freedb_search, NULL, TRUE, NULL);
+  create_thread(freedb_search, NULL, TRUE, NULL);
 }
 
-//we push the search button
+//!we push the search button
 void freedb_search_button_event(GtkWidget *widget, gpointer   data)
 {
   freedb_search_start_thread();
 }
 
-//search entry backspace event
-//when we push Enter for the search entry
+/*!search entry backspace event
+
+when we push Enter for the search entry
+*/
 void freedb_entry_activate_event(GtkEntry *entry, gpointer data)
 {
   freedb_search_start_thread();
 }
 
-//returns the number of splitpoints
-//we put the new splitpoints in "the_state"
+/*!returns the number of splitpoints
+
+we put the new splitpoints in "the_state"
+*/
 void write_freedbfile(int *err)
 {
   gchar *filename = NULL;
  
-  gdk_threads_enter();
+  enter_threads();
    
   put_status_message(_("please wait... contacting tracktype.org"));
   
@@ -401,7 +407,7 @@ void write_freedbfile(int *err)
              G_DIR_SEPARATOR_S, mp3splt_dir,
              G_DIR_SEPARATOR_S, "query.cddb");
  
-  gdk_threads_leave();
+  exit_threads();
 
   //we write the freedb file ...
   mp3splt_write_freedb_file_result(the_state, selected_id,
@@ -410,9 +416,9 @@ void write_freedbfile(int *err)
                                    SPLT_FREEDB_GET_FILE_TYPE_CDDB_CGI,
                                    "\0",-1);
 
-  gdk_threads_enter();
+  enter_threads();
   print_status_bar_confirmation(*err);
-  gdk_threads_leave();
+  exit_threads();
 
   if(get_checked_output_radio_box())
   {
@@ -427,9 +433,9 @@ void write_freedbfile(int *err)
     const char *data = gtk_entry_get_text(GTK_ENTRY(output_entry));
     gint error = SPLT_OUTPUT_FORMAT_OK;
     mp3splt_set_oformat(the_state, data, &error);
-    gdk_threads_enter();
+    enter_threads();
     print_status_bar_confirmation(error);
-    gdk_threads_leave();
+    exit_threads();
   }
 
   mp3splt_put_cddb_splitpoints_from_file(the_state,filename, err);
@@ -441,7 +447,7 @@ void write_freedbfile(int *err)
   }
 }
 
-//returns the seconds, minutes, and hudreths
+//!returns the seconds, minutes, and hudreths
 void get_secs_mins_hundr(gfloat time,
                          gint *mins,gint *secs, 
                          gint *hundr)
@@ -453,17 +459,20 @@ void get_secs_mins_hundr(gfloat time,
                   - (*secs * 100));
 }
 
-//updates the current splitpoints int the table,
-//from the state splitpoints
-//max_splits is the maximum splitpoints to update
+/*!updates the current splitpoints in the_state
+
+Takes the splitpoints from the table displayed in the gui
+
+max_splits is the maximum number of splitpoints to update
+*/
 void update_splitpoints_from_the_state()
 {
   gint max_splits = 0;
   gint err = SPLT_OK;
 
-  gdk_threads_leave();
+  exit_threads();
   const splt_point *points = mp3splt_get_splitpoints(the_state, &max_splits,&err);
-  gdk_threads_enter();
+  enter_threads();
 
   print_status_bar_confirmation(err);
   
@@ -539,31 +548,31 @@ gpointer put_freedb_splitpoints(gpointer data)
 {
   gint err = SPLT_OK;
 
-  gdk_threads_enter();
+  enter_threads();
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_add_button), FALSE);  
-  gdk_threads_leave();
+  exit_threads();
  
   write_freedbfile(&err);
  
-  gdk_threads_enter();
+  enter_threads();
  
   update_splitpoints_from_the_state();
   print_status_bar_confirmation(err);
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_add_button), TRUE);
 
-  gdk_threads_leave();
+  exit_threads();
   
   return NULL;
 }
 
-//event for the freedb add button when clicked
+//!event for the freedb add button when clicked
 void freedb_add_button_clicked_event(GtkButton *button, gpointer data)
 {
   mp3splt_set_int_option(the_state, SPLT_OPT_DEBUG_MODE, debug_is_active);
-  g_thread_create(put_freedb_splitpoints, NULL, TRUE, NULL);
+  create_thread(put_freedb_splitpoints, NULL, TRUE, NULL);
 }
 
-//creates the freedb box
+//!creates the freedb box
 GtkWidget *create_freedb_frame()
 {
   //main freedb box
@@ -593,7 +602,7 @@ GtkWidget *create_freedb_frame()
   gtk_box_pack_start(GTK_BOX(search_hbox), label, FALSE, FALSE, 0);
   //top entry
   freedb_entry = gtk_entry_new();
-  gtk_entry_set_editable(GTK_ENTRY(freedb_entry), TRUE);
+  gtk_editable_set_editable(GTK_EDITABLE(freedb_entry), TRUE);
   gtk_box_pack_start(GTK_BOX(search_hbox), freedb_entry, TRUE, TRUE, 6);
   g_signal_connect(G_OBJECT(freedb_entry), "activate",
       G_CALLBACK(freedb_entry_activate_event), NULL);
@@ -643,7 +652,7 @@ GtkWidget *create_freedb_frame()
   gtk_box_pack_start(GTK_BOX(selected_hbox), label_selected , FALSE, FALSE, 0);
   //freedb selected entry
   freedb_selected_entry = gtk_entry_new();
-  gtk_entry_set_editable(GTK_ENTRY(freedb_selected_entry), FALSE);
+  gtk_editable_set_editable(GTK_EDITABLE(freedb_selected_entry), FALSE);
   gtk_box_pack_start(GTK_BOX(selected_hbox), freedb_selected_entry, TRUE, TRUE, 6);
   //add button
   freedb_add_button = (GtkWidget *)
