@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * from BMP to Audacious patch from Roberto Neri - 2007,2008
@@ -31,11 +31,12 @@
  *
  *********************************************************/
 
-/**********************************************************
- * Filename: gstreamer_control.c
- *
- * this file has functions to control the 'internal' gstreamer player
+/*!*******************************************************
+ * \file 
+ * Control the gstreamer framework
  *
+ * this file has functions to control the 'internal' 
+ + gstreamer player
  *********************************************************/
 
 #include <stdlib.h>
@@ -53,6 +54,8 @@
 #include "player.h"
 #include "main_win.h"
 #include "utilities.h"
+#include "player_tab.h"
+#include "mp3splt-gtk.h"
 
 extern int selected_player;
 
@@ -65,12 +68,12 @@ gint rate = 0;
 GstElement *play = NULL;
 GstBus *bus = NULL;
 gint _gstreamer_is_running = FALSE;
-extern GtkWidget *entry;
 extern GtkWidget *playlist_box;
 extern GtkWidget *player_vbox;
 
 extern void add_playlist_file(const gchar *name);
 
+//! Send a call over the dbus
 static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data)
 {
   switch (GST_MESSAGE_TYPE(msg))
@@ -93,9 +96,9 @@ static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data)
           memset(message,'\0',malloc_size);
           g_snprintf(message, malloc_size,_("gstreamer error: %s"),error->message);
 
-          gdk_threads_enter();
+          enter_threads();
           put_status_message(message);
-          gdk_threads_leave();
+          exit_threads();
 
           g_free(message);
         }
@@ -121,9 +124,9 @@ static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data)
           memset(message,'\0',malloc_size);
           g_snprintf(message, malloc_size,_("Warning: %s"),error->message);
 
-          gdk_threads_enter();
+          enter_threads();
           put_status_message(message);
-          gdk_threads_leave();
+          exit_threads();
 
           g_free(message);
         }
@@ -149,9 +152,9 @@ static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data)
           memset(message,'\0',malloc_size);
           g_snprintf(message, malloc_size,_("Info: %s"),error->message);
 
-          gdk_threads_enter();
+          enter_threads();
           put_status_message(message);
-          gdk_threads_leave();
+          exit_threads();
 
           g_free(message);
         }
@@ -198,7 +201,7 @@ static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data)
   return TRUE;
 }
 
-//Gets informations about the song
+//!Gets information about the< song
 void gstreamer_get_song_infos(gchar *total_infos)
 {
 	if (play)
@@ -269,21 +272,25 @@ void gstreamer_get_song_infos(gchar *total_infos)
 	}
 }
 
-//returns the filename
-//must be freed after
+/*! returns the filename
+
+The result must be g_free'd after use.
+*/
 gchar *gstreamer_get_filename()
 {
-  return strdup(gtk_entry_get_text(GTK_ENTRY(entry)));
+  return strdup(inputfilename_get());
 }
 
-//returns the number of songs of the playlist
+//!returns the number of songs of the playlist
 gint gstreamer_get_playlist_number()
 {
   return 1;
 }
 
-//returns the title of the song
-//must be freed after
+/*!returns the title of the song
+
+The result must be g_free'd after use
+*/
 gchar *gstreamer_get_title_song()
 {
   if (song_artist || song_title)
@@ -343,7 +350,7 @@ gchar *gstreamer_get_title_song()
   }
 }
 
-//returns elapsed time
+//!returns elapsed time
 gint gstreamer_get_time_elapsed()
 {
 	if (play)
@@ -366,7 +373,7 @@ gint gstreamer_get_time_elapsed()
 	}
 }
 
-//starts gstreamer
+//!starts gstreamer
 void gstreamer_start()
 {
   if (play)
@@ -397,7 +404,7 @@ void gstreamer_start()
 		gst_object_unref(bus);
 
 		//add the current filename
-		const gchar *fname =  gtk_entry_get_text(GTK_ENTRY(entry));
+		const gchar *fname =  inputfilename_get();
 		GList *song_list = NULL;
 		song_list = g_list_append(song_list, strdup(fname));
 		gstreamer_add_files(song_list);
@@ -405,25 +412,25 @@ void gstreamer_start()
 	}
 	else
 	{
-		gdk_threads_enter();
+		enter_threads();
 		put_status_message(_(" error: cannot create gstreamer playbin\n"));
-		gdk_threads_leave();
+		exit_threads();
 	}
 }
 
-//selects the last file in the playlist
+//!selects the last file in the playlist
 void gstreamer_select_last_file()
 {
 }
 
-//plays the last file of the playlist
+//!plays the last file of the playlist
 void gstreamer_play_last_file()
 {
   gstreamer_stop();
   gstreamer_play();
 }
 
-//add files to the gstreamer playlist
+//!add files to the gstreamer playlist
 void gstreamer_add_files(GList *list)
 {
   gchar *song = NULL;
@@ -463,7 +470,7 @@ void gstreamer_add_files(GList *list)
   }
 }
 
-//sets volume
+//!sets volume
 void gstreamer_set_volume(gint volume)
 {
 	if (play)
@@ -474,7 +481,7 @@ void gstreamer_set_volume(gint volume)
 	}
 }
 
-//returns volume
+//!returns volume
 gint gstreamer_get_volume()
 {
 	if (play)
@@ -492,7 +499,7 @@ gint gstreamer_get_volume()
 	}
 }
 
-//starts gstreamer with songs
+//!starts gstreamer with songs
 void gstreamer_start_with_songs(GList *list)
 {
   gstreamer_start();
@@ -500,13 +507,13 @@ void gstreamer_start_with_songs(GList *list)
   gstreamer_play();
 }
 
-//returns TRUE if gstreamer is running; if not, FALSE 
+//!returns TRUE if gstreamer is running; if not, FALSE 
 gint gstreamer_is_running()
 {
   return _gstreamer_is_running;
 }
 
-//returns TRUE if gstreamer is paused, if not, FALSE 
+//!returns TRUE if gstreamer is paused, if not, FALSE 
 gint gstreamer_is_paused()
 {
 	if (play)
@@ -529,7 +536,7 @@ gint gstreamer_is_paused()
 	}
 }
 
-//plays a song
+//!plays a song
 void gstreamer_play()
 {
 	if (play)
@@ -548,7 +555,7 @@ void gstreamer_play()
   }
 }
 
-//stops a song
+//!stops a song
 void gstreamer_stop()
 {
 	if (play)
@@ -557,7 +564,7 @@ void gstreamer_stop()
 	}
 }
 
-//pause a song
+//!pause a song
 void gstreamer_pause()
 {
 	if (play)
@@ -576,17 +583,17 @@ void gstreamer_pause()
   }
 }
 
-//changes to next song
+//!changes to next song
 void gstreamer_next()
 {
 }
 
-//changes to previous song
+//!changes to previous song
 void gstreamer_prev()
 {
 }
 
-//jump to time
+//!jump to time
 void gstreamer_jump(gint position)
 {
 	if (play)
@@ -597,7 +604,7 @@ void gstreamer_jump(gint position)
 	}
 }
 
-//returns total time of the current song
+//!returns total time of the current song
 gint gstreamer_get_total_time()
 {
 	if (play)
@@ -622,7 +629,7 @@ gint gstreamer_get_total_time()
 	}
 }
 
-//returns TRUE if gstreamer is playing, else FALSE
+//!returns TRUE if gstreamer is playing, else FALSE
 gint gstreamer_is_playing()
 {
 	if (play)
@@ -645,7 +652,7 @@ gint gstreamer_is_playing()
 	}
 }
 
-//quits player
+//!quits player
 void gstreamer_quit()
 {
   if (play)
