@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -29,8 +29,9 @@
  *
  *********************************************************/
 
-/**********************************************************
- * Filename: main_win.c
+/*!********************************************************
+ * \file 
+ * The main window
  *
  * main file that initialises the menubar, the toolbar, 
  * the tabs, about window, status error messages
@@ -41,11 +42,12 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #else
-#define VERSION "0.6"
+#define VERSION "0.7.1"
 #define PACKAGE_NAME "mp3splt-gtk"
 #endif
 
 #include <string.h>
+#include "export.h"
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
@@ -73,6 +75,9 @@
 #include "messages.h"
 #include "import.h"
 #include "preferences_manager.h"
+#include "player_tab.h"
+
+#include "ui_manager.h"
 
 //main window
 GtkWidget *window = NULL;
@@ -87,8 +92,6 @@ gint preferences_tab = FALSE;
 //player box
 GtkWidget *player_box;
 
-//the split button
-GtkWidget *split_button;
 //the split freedb button
 GtkWidget *split_freedb_button;
 
@@ -110,32 +113,36 @@ GtkWidget *cancel_button = NULL;
 
 extern GtkWidget *mess_history_dialog;
 
-extern GtkWidget *entry;
-extern GtkWidget *directory_entry;
+extern GtkWidget *da;
+extern GtkWidget *progress_bar;
+
 extern GArray *splitpoints;
 extern gint selected_id;
 extern splt_state *the_state;
 extern splt_freedb_results *search_results;
 extern GList *player_pref_list;
+extern GList *text_options_list;
 extern gchar **split_files;
 extern gint max_split_files;
 extern gint selected_player;
 extern silence_wave *silence_points;
 extern gint number_of_silence_points;
 
+extern ui_state *ui;
+
 GtkWidget *playlist_box = NULL;
 
 //close the window and exit button function
 void quit(GtkWidget *widget, gpointer   data)
 {
-  //if we are in the middle of the split
+  save_preferences(NULL, NULL);
+
   if (we_are_splitting)
   {
     gint err = SPLT_OK;
     mp3splt_stop_split(the_state,&err);
     print_status_bar_confirmation(err);
 
-    //wait to finish split then quit
     we_quit_main_program = TRUE;
     put_status_message(_(" info: stopping the split process before exiting"));
   }
@@ -147,6 +154,7 @@ void quit(GtkWidget *widget, gpointer   data)
   }
 
   g_list_free(player_pref_list);
+  g_list_free(text_options_list);
   g_array_free(splitpoints, TRUE);
 
   if (silence_points)
@@ -156,10 +164,6 @@ void quit(GtkWidget *widget, gpointer   data)
     number_of_silence_points = 0;
   }
 
-  gint err = SPLT_OK;
-  mp3splt_free_state(the_state, &err);
-  print_status_bar_confirmation(err);
-
   gtk_main_quit();
 }
 
@@ -167,7 +171,7 @@ void main_window_drag_data_received(GtkWidget *window,
     GdkDragContext *drag_context, gint x, gint y, GtkSelectionData *data, guint
     info, guint time, gpointer user_data)
 {
-  const gchar *received_data = (gchar *) data->data;
+  const gchar *received_data = (gchar *) gtk_selection_data_get_text(data);
 
   if (received_data != NULL)
   {
@@ -216,13 +220,25 @@ void main_window_drag_data_received(GtkWidget *window,
   }
 }
 
-//initializes window
+gboolean configure_window_callback(GtkWindow *window, GdkEvent *event, gpointer data)
+{
+  ui_state *ui = (ui_state *)data;
+
+  ui_set_main_win_position(ui, event->configure.x, event->configure.y); 
+  ui_set_main_win_size(ui, event->configure.width, event->configure.height);
+
+  return FALSE;
+}
+
 void initialize_window()
 {
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+
+  g_signal_connect(G_OBJECT(window), "configure-event", G_CALLBACK(configure_window_callback), ui);
+
   window_accel_group = gtk_accel_group_new();
   gtk_window_add_accel_group(GTK_WINDOW(window), window_accel_group);
-   
+ 
   gtk_window_set_title(GTK_WINDOW(window), PACKAGE_NAME" "VERSION);
   gtk_container_set_border_width (GTK_CONTAINER (window), 0);
 
@@ -232,12 +248,11 @@ void initialize_window()
   gtk_drag_dest_set(window, GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_DROP,
       drop_types, 3, GDK_ACTION_COPY | GDK_ACTION_MOVE);
  
-  gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
- 
-  //for the bitmap
-  GdkPixbuf *pixbuf =
-    gdk_pixbuf_new_from_file(PIXMAP_PATH"mp3splt-gtk_ico.png", NULL);
+  GString *Imagefile = g_string_new(PIXMAP_PATH);
+  build_svg_path(Imagefile, "mp3splt-gtk_ico"ICON_EXT);
+  GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file(Imagefile->str, NULL);
   gtk_window_set_default_icon(pixbuf);
+  g_string_free(Imagefile, TRUE);
 }
 
 void activate_url(GtkAboutDialog *about, const gchar *link, gpointer data)
@@ -295,7 +310,7 @@ void activate_url(GtkAboutDialog *about, const gchar *link, gpointer data)
         if (! CreateProcess(NULL, browser_command,
               NULL, NULL, FALSE, 0, NULL, NULL, &si, &pinf))
         {
-          put_status_message("Error launching external command");
+          put_status_message(_("Error launching external command"));
         }
 
         CloseHandle(pinf.hProcess);
@@ -318,10 +333,10 @@ void about_window(GtkWidget *widget, gpointer *data)
       NULL);
   gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(dialog), pixbuf);
   
-  gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(dialog), (gchar *)PACKAGE_NAME);
+  gtk_about_dialog_set_program_name(GTK_ABOUT_DIALOG(dialog), (gchar *)PACKAGE_NAME);
   gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(dialog), VERSION);
   gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(dialog),
-                                 PACKAGE_NAME" : Copyright © 2005-2010 Alexandru"
+                                 PACKAGE_NAME" : Copyright © 2005-2011 Alexandru"
                                  " Munteanu \n mp3splt : Copyright © 2002-2005 Matteo Trotta");
 
   gchar *b1 = NULL;
@@ -329,8 +344,8 @@ void about_window(GtkWidget *widget, gpointer *data)
   b1 = (gchar *)_("using");
   gchar library_version[20] = { '\0' };
   mp3splt_get_version(library_version);
-  g_snprintf(b3, 100, "-%s 16/05/09-\n%s libmp3splt %s",
-             _("release of"), b1, library_version);
+  g_snprintf(b3, 100, "-%s-\n%s libmp3splt %s",
+             _("release of "MP3SPLT_GTK_DATE), b1, library_version);
   
   gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(dialog), b3);
   
@@ -356,7 +371,7 @@ void about_window(GtkWidget *widget, gpointer *data)
                                 "Suite 330, Boston, MA  02111-1307, "
                                 "USA.");
 
-  gtk_about_dialog_set_url_hook(activate_url, NULL, NULL);
+  g_signal_connect(G_OBJECT(dialog), "activate-link", G_CALLBACK(activate_url), NULL);
 
   gtk_about_dialog_set_website_label(GTK_ABOUT_DIALOG(dialog),
       "http://mp3splt.sourceforge.net");
@@ -370,8 +385,10 @@ void about_window(GtkWidget *widget, gpointer *data)
   gtk_widget_destroy(dialog);
 }
 
-//used  for the ok button event
-//removes status bar message
+/*! Removes status bar message
+
+Used for the ok button event.
+*/
 void remove_status_message()
 {
   guint status_id =
@@ -379,11 +396,27 @@ void remove_status_message()
   gtk_statusbar_pop(GTK_STATUSBAR(status_bar), status_id);
 }
 
+/*! Output a info message to the status message bar
+
+The message type is automatically set to SPLT_MESSAGE_INFO.
+If you don't want that use put_status_message instead.
+\param text The text that has to be displayed.
+*/
+
 void put_status_message(const gchar *text)
 {
   put_status_message_with_type(text, SPLT_MESSAGE_INFO);
 }
 
+/*! Output a message to the status message bar.
+
+\param text The text that has to be displayed.
+\param splt_message_type The type of the message.
+
+If the type is to be set to SPLT_MESSAGE_INFO put_status_message
+can be used instead; The enum for the message types is defined in
+libmp3splt.h
+ */
 void put_status_message_with_type(const gchar *text, splt_message_type mess_type)
 {
   if (mess_type == SPLT_MESSAGE_INFO)
@@ -398,7 +431,7 @@ void put_status_message_with_type(const gchar *text, splt_message_type mess_type
   put_message_in_history(text, mess_type);
 }
 
-//event for the split button
+//!event for the cancel button
 void cancel_button_event(GtkWidget *widget, gpointer data)
 {
   gint err = SPLT_OK;
@@ -412,7 +445,7 @@ void cancel_button_event(GtkWidget *widget, gpointer data)
   put_status_message(_(" info: stopping the split process.. please wait"));
 }
 
-//event for the split button
+//!event for the split button
 void split_button_event(GtkWidget *widget, gpointer data)
 {
   //if we are not splitting
@@ -436,15 +469,14 @@ void split_button_event(GtkWidget *widget, gpointer data)
       }
     }
 
-    filename_to_split = (gchar *) gtk_entry_get_text(GTK_ENTRY(entry));
+    filename_to_split = inputfilename_get();
 
-    filename_path_of_split = (gchar *)
-      gtk_entry_get_text(GTK_ENTRY(directory_entry));
+    filename_path_of_split = outputdirectory_get();
 
     if (filename_path_of_split != NULL)
     {
       we_are_splitting = TRUE;
-      g_thread_create(split_it, NULL, TRUE, NULL);
+      create_thread(split_it, NULL, TRUE, NULL);
       gtk_widget_set_sensitive(GTK_WIDGET(cancel_button), TRUE);
     }
     else
@@ -458,90 +490,118 @@ void split_button_event(GtkWidget *widget, gpointer data)
   }
 }
 
-//creates the toolbar
+//!creates the toolbar
 GtkWidget *create_toolbar()
 {
-  //the toolbar
-  GtkWidget *toolbar = gtk_toolbar_new();
-  
-  //separator
-  GtkWidget *toolbar_button = (GtkWidget *)gtk_separator_tool_item_new();
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(toolbar_button), 0);
-  gtk_tool_item_set_expand(GTK_TOOL_ITEM(toolbar_button), TRUE);
-  gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolbar_button),
-                                   FALSE);
-  
-  //split button
-  split_button = (GtkWidget *)gtk_tool_button_new_from_stock(GTK_STOCK_APPLY);
-  gtk_widget_set_tooltip_text(split_button, _("Split !"));
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(split_button), 1);
+  GtkWidget *box = gtk_hbox_new(FALSE, 0);
+  gtk_container_set_border_width(GTK_CONTAINER(box), 0);
+  gtk_box_pack_start(GTK_BOX(box), 
+      gtk_image_new_from_stock(GTK_STOCK_APPLY, GTK_ICON_SIZE_SMALL_TOOLBAR), 
+      FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(box), gtk_label_new(_("Split !")), FALSE, FALSE, 0);
+
+  GtkWidget *split_button = gtk_button_new();
+  gtk_container_add(GTK_CONTAINER(split_button), box);
+  gtk_widget_set_tooltip_text(split_button,_("Split !"));
+  gtk_container_set_border_width(GTK_CONTAINER(split_button), 0);
+  gtk_button_set_relief(GTK_BUTTON(split_button), GTK_RELIEF_HALF);
+
   g_signal_connect(G_OBJECT(split_button), "clicked",
       G_CALLBACK(split_button_event), NULL);
-  
-  //separator
-  toolbar_button = (GtkWidget *)gtk_separator_tool_item_new();
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(toolbar_button), 2);
-  gtk_tool_item_set_expand(GTK_TOOL_ITEM(toolbar_button), TRUE);
-  gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolbar_button),
-                                   FALSE);
 
-  //toolbar preferences
-  gtk_toolbar_set_show_arrow(GTK_TOOLBAR(toolbar), TRUE);
-  gtk_toolbar_set_icon_size(GTK_TOOLBAR(toolbar), GTK_ICON_SIZE_SMALL_TOOLBAR);
-  gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_ICONS);
-  
-  return toolbar;
+  GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
+  GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
+
+  gtk_box_pack_start(GTK_BOX(hbox), split_button, TRUE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+
+  return vbox;
 }
 
-//event for the split button
+//!event for the "messages history" button
 void show_messages_history_dialog(GtkWidget *widget, gpointer data)
 {
   gtk_widget_show_all(GTK_WIDGET(mess_history_dialog));
 }
 
-//creates the menu bar
+#ifndef NO_GNOME
+void ShowHelp()
+{
+  GError* gerror = NULL;
+  gtk_show_uri(gdk_screen_get_default(), "ghelp:mp3splt-gtk",  gtk_get_current_event_time(), &gerror);
+}
+#endif
+
+static gchar *my_dgettext(const gchar *key, const gchar *domain)
+{
+  return dgettext("mp3splt-gtk", key);
+}
+
+//!creates the menu bar
 GtkWidget *create_menu_bar()
 {
   GtkWidget *menu_box = gtk_hbox_new(FALSE,0);
   
-  //define the menu
   static GtkActionEntry const entries[] = {
     //name, stock id,   label
     { "FileMenu", NULL, N_("_File") },  
     { "HelpMenu", NULL, N_("_Help") },
+
     //name, stock id, label, accelerator, tooltip
+    { "Open", GTK_STOCK_OPEN, N_("_Open..."), "<Ctrl>O", N_("Open"),
+      G_CALLBACK(browse_button_event) },
+
+    { "Import", GTK_STOCK_FILE, N_("_Import splitpoints..."), "<Ctrl>I", N_("Import"),
+      G_CALLBACK(import_event) },
+    { "Export", GTK_STOCK_SAVE_AS, N_("_Export splitpoints..."), "<Ctrl>E", N_("Export"),
+      G_CALLBACK(ChooseCueExportFile) },
+
     { "Split", GTK_STOCK_APPLY, N_("_Split !"), "<Ctrl>S", N_("Split"),
       G_CALLBACK(split_button_event) },
-    { "Import", GTK_STOCK_OPEN, N_("_Import..."), "<Ctrl>I", N_("Import"),
-      G_CALLBACK(import_event) },
     { "Messages history", GTK_STOCK_INFO, N_("Messages _history"), "<Ctrl>H", N_("Messages history"),
       G_CALLBACK(show_messages_history_dialog) },
+
     { "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<Ctrl>Q", N_("Quit"),
       G_CALLBACK(quit) },
-    //name, stock id, label, accelerator
+
+#ifndef NO_GNOME
+    { "Contents", GTK_STOCK_HELP, N_("_Contents"), "F1", N_("Contents"),
+      G_CALLBACK(ShowHelp)},
+#endif
+
     { "About", GTK_STOCK_ABOUT, N_("_About"), "<Ctrl>A", N_("About"),
       G_CALLBACK(about_window)},
   };
-  //build the menu
+
   static const gchar *ui_info = 
     "<ui>"
     "  <menubar name='MenuBar'>"
     "    <menu action='FileMenu'>"
-    "      <menuitem action='Split'/>"
+    "      <menuitem action='Open'/>"
+    "      <separator/>"
     "      <menuitem action='Import'/>"
+    "      <menuitem action='Export'/>"
+    "      <separator/>"
+    "      <menuitem action='Split'/>"
     "      <menuitem action='Messages history'/>"
     "      <separator/>"
     "      <menuitem action='Quit'/>"
     "    </menu>"
     "    <menu action='HelpMenu'>"
+#ifndef NO_GNOME
+    "      <menuitem action='Contents'/>"
+#endif
     "      <menuitem action='About'/>"
     "    </menu>"
     "  </menubar>"
     "</ui>";
 
   GtkActionGroup *actions = gtk_action_group_new ("Actions");
-  //translation
+
   gtk_action_group_set_translation_domain(actions, "mp3splt-gtk");
+  gtk_action_group_set_translate_func(actions,
+                  (GtkTranslateFunc)my_dgettext, NULL, NULL);
+
   //adding the GtkActionEntry to GtkActionGroup
   gtk_action_group_add_actions (actions, entries, G_N_ELEMENTS(entries), NULL);
   GtkUIManager *ui = gtk_ui_manager_new ();
@@ -558,19 +618,19 @@ GtkWidget *create_menu_bar()
                       gtk_ui_manager_get_widget(ui, "/MenuBar"),
                       FALSE, FALSE, 0);
   
-  //our toolbar
-  GtkWidget *toolbar;
-  toolbar = (GtkWidget *)create_toolbar();
-  
-  //attach the toolbar
-  gtk_box_pack_start (GTK_BOX (menu_box), toolbar,
-                      TRUE, TRUE, 0);
+  GtkWidget *toolbar = (GtkWidget *)create_toolbar();
+  gtk_box_pack_start(GTK_BOX(menu_box), toolbar, TRUE, TRUE, 0);
   
   return menu_box;
 }
 
-//creates a cool button with image from stock
-//toggle_or_not = TRUE means we create a toggle button
+/*!creates a cool button with image from stock
+
+\param label_text The text that has to be displayed on the button
+\param stock_id The name of the stock image to be displayed on the
+	button 
+\param toggle_or_not TRUE means we create a toggle button
+*/
 GtkWidget *create_cool_button(gchar *stock_id, gchar *label_text,
     gint toggle_or_not)
 {
@@ -606,7 +666,7 @@ GtkWidget *create_cool_button(gchar *stock_id, gchar *label_text,
   return button;
 }
 
-//main vbox
+//!main vbox
 GtkWidget *create_main_vbox()
 {
   //big ain box contailning all with statusbar
@@ -670,7 +730,7 @@ GtkWidget *create_main_vbox()
   
   frame = (GtkWidget *)create_split_files();
   gtk_container_add(GTK_CONTAINER(split_files_vbox), frame);
-  
+
   notebook_label = gtk_label_new((gchar *)_("Split files"));
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), 
                            split_files_vbox,
@@ -746,7 +806,9 @@ GtkWidget *create_main_vbox()
  
   /* statusbar */
   status_bar = gtk_statusbar_new();
-  gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(status_bar), FALSE);
+
+  //TODO: gtk+ >= 3
+  //gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(status_bar), FALSE);
 
   GtkWidget *mess_history_button =
     create_cool_button(GTK_STOCK_INFO, NULL, FALSE);
@@ -761,7 +823,25 @@ GtkWidget *create_main_vbox()
   return main_vbox;
 }
 
-//main function, creates all the window
+static void move_and_resize_main_window()
+{
+  const ui_main_window *main_win = ui_get_main_window_infos(ui);
+
+  gint x = main_win->root_x_pos;
+  gint y = main_win->root_y_pos;
+
+  if (x != 0 && y != 0)
+  {
+    gtk_window_move(GTK_WINDOW(window), x, y);
+  }
+  else
+  {
+    gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
+  }
+
+  gtk_window_resize(GTK_WINDOW(window), main_win->width, main_win->height);
+}
+
 void create_all()
 {
 #ifdef __WIN32__
@@ -773,32 +853,32 @@ void create_all()
   GtkWidget *window_vbox = gtk_vbox_new(FALSE, 0);
   gtk_container_add(GTK_CONTAINER(window), window_vbox);
 
-  /* menu bar */
   GtkWidget *menu_bar;
   menu_bar = (GtkWidget *)create_menu_bar();
   gtk_box_pack_start(GTK_BOX(window_vbox), menu_bar, FALSE, FALSE, 0);  
-  
-  /* main vbox */
+ 
   GtkWidget *main_vbox = (GtkWidget *)create_main_vbox();
   gtk_box_pack_start(GTK_BOX(window_vbox), main_vbox, TRUE, TRUE, 0);
   
-  gtk_widget_show_all(window);
- 
-  hide_disconnect_button();
-  gtk_widget_hide(playlist_box);
-
-  //load preferences
   load_preferences();
-  combo_remove_unavailable_players();
 
-  //hide connect button if player is gstreamer
   if (selected_player == PLAYER_GSTREAMER)
   {
     hide_connect_button();
   }
+
+  hide_disconnect_button();
+  gtk_widget_hide(playlist_box);
+
+  move_and_resize_main_window();
+
+  gtk_widget_show_all(window);
 }
 
-//print the status bar confirmation
+/*!Output an error message from libmp3splt to the status bar
+
+  \param The error number from the library.
+ */
 void print_status_bar_confirmation(gint confirmation)
 {
   char *error_from_library = mp3splt_get_strerror(the_state, confirmation);
@@ -809,4 +889,3 @@ void print_status_bar_confirmation(gint confirmation)
     error_from_library = NULL;
   }
 }
-
