@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -44,6 +44,7 @@
 
 #ifdef __WIN32__
 #define PIXMAP_PATH ""
+#define IMAGEDIR ""
 #endif
 
 #define WINDOW_X 700
@@ -75,14 +76,11 @@ GtkWidget *create_toolbar();
 GtkWidget *create_menu_bar();
 GtkWidget *create_cool_button(gchar *stock_id, gchar *label_text,
     gint toggle_or_not);
-void notebook_page_changed_event(GtkNotebook *notebook,
-                                 GtkNotebookPage *page,
-                                 guint page_num,
-                                 gpointer user_data);
 GtkWidget *create_main_vbox();
 void create_all();
 void print_status_bar_confirmation(gint confirmation);
 void cancel_button_event(GtkWidget *widget, gpointer data);
+void put_status_message(const gchar *text);
 
 #endif
 
