@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -29,11 +29,9 @@
  *
  *********************************************************/
 
-/**********************************************************
- * Filename: messages.c
- *
- * messages history dialog
- *
+/*!********************************************************
+ * \file 
+ * The messages history dialog
  *********************************************************/
 
 #include <gtk/gtk.h>
@@ -49,8 +47,11 @@ GtkTextTagTable *mess_hist_tag_table = NULL;
 GtkWidget *mess_hist_view = NULL;
 gint debug_is_active = FALSE;
 
+void create_mess_history_dialog();
+
 extern splt_state *the_state;
 
+//! Returns the current local time in form of a string
 const char *get_current_time()
 {
   time_t cur_time = { 0 };
@@ -62,6 +63,7 @@ const char *get_current_time()
   return time_str;
 }
 
+//! Record this message in the message history
 void put_message_in_history(const gchar *message, splt_message_type mess_type)
 {
   if (mess_type == SPLT_MESSAGE_INFO ||
@@ -88,16 +90,26 @@ void put_message_in_history(const gchar *message, splt_message_type mess_type)
   }
 }
 
+//! Hide the message history dialog
 void mess_history_hide(GtkDialog *dialog, gint response_id, gpointer data)
 {
   gtk_widget_hide(mess_history_dialog);
 }
 
+/*! Hide the message history dialog
+
+Takes less arguments than mess_history_hide. 
+\todo Do we really still need both functions doing the same? They
+do not seem to use the arguments they differ in at all
+ */
 void mess_history_hide2(GtkWidget *widget, gpointer data)
 {
   mess_history_hide(NULL, 0, NULL);
+  //TODO: ugly HACK!
+  create_mess_history_dialog();
 }
 
+//! Add tags to the message history entry
 void add_mess_hist_tags()
 {
   GtkTextTag *tag = gtk_text_tag_new("gray_bold");
@@ -110,6 +122,7 @@ void add_mess_hist_tags()
   gtk_text_tag_table_add(mess_hist_tag_table, tag);
 }
 
+//! The event that is issued if the user clicks on a message tag
 void debug_check_event(GtkToggleButton *debug_toggle, gpointer user_data)
 {
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(debug_toggle)))
@@ -122,6 +135,7 @@ void debug_check_event(GtkToggleButton *debug_toggle, gpointer user_data)
   }
 }
 
+//! The event issued when the "Clear messages" button is clicked
 void clear_messages_event(GtkWidget *widget, gpointer data)
 {
   GtkTextIter start_iter;
@@ -130,7 +144,8 @@ void clear_messages_event(GtkWidget *widget, gpointer data)
   gtk_text_buffer_get_end_iter(mess_hist_buffer, &end_iter);
   gtk_text_buffer_delete(mess_hist_buffer, &start_iter, &end_iter);
 }
- 
+
+//! The portion of the message history dialog that contains the messages
 GtkWidget *create_text_component()
 {
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
@@ -180,11 +195,11 @@ GtkWidget *create_text_component()
   return vbox;
 }
 
+//! Create the message history dialog
 void create_mess_history_dialog()
 {
   mess_history_dialog = gtk_dialog_new_with_buttons(_("Messages history"), NULL,
-      GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
-      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
+      GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
 
   gtk_window_set_default_size(GTK_WINDOW(mess_history_dialog), 550, 300);
 
@@ -196,7 +211,7 @@ void create_mess_history_dialog()
   gtk_window_set_position(GTK_WINDOW(mess_history_dialog), GTK_WIN_POS_CENTER);
 
   GtkWidget *text_component = create_text_component();
-  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(mess_history_dialog)->vbox),
-      text_component);
+  GtkWidget *area = gtk_dialog_get_content_area(GTK_DIALOG(mess_history_dialog));
+  gtk_box_pack_start(GTK_BOX(area), text_component, TRUE, TRUE, 0);
 }
 
