@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -29,13 +29,28 @@
  *
  *********************************************************/
 
+/*!********************************************************
+ * \file 
+ * The main file,
+ *
+ * this file contains the main() function as well as some 
+ * globally used functions.
+ *********************************************************/
+
 #include <signal.h>
+#include <locale.h>
+#include <string.h>
+#include <ctype.h>
+#include <unistd.h>
+
+#include <sys/stat.h>
+#include <sys/types.h>
+
+#include <glib/gi18n.h>
+#include <glib.h>
+
 #include <gtk/gtk.h>
 #include <libmp3splt/mp3splt.h>
-#include <locale.h>
-#include <glib/gi18n.h>
-#include <string.h>
-#include <glib.h>
 
 #ifdef __WIN32__
 #include <windows.h>
@@ -53,6 +68,11 @@
 #include "preferences_tab.h"
 #include "multiple_files.h"
 #include "preferences_manager.h"
+#include "player_tab.h"
+#include "import.h"
+#include "mp3splt-gtk.h"
+
+#include "ui_manager.h"
 
 //the state
 splt_state *the_state = NULL;
@@ -62,7 +82,6 @@ GtkWidget *progress_bar;
 
 extern GArray *splitpoints;
 extern gint splitnumber;
-extern GList *player_pref_list;
 extern GtkWidget *queue_files_button;
 extern gchar *filename_to_split;
 extern gchar *filename_path_of_split;
@@ -112,8 +131,6 @@ extern GtkWidget *cancel_button;
 //the output entry
 extern GtkWidget *output_entry;
 
-extern GtkWidget *split_button;
-
 extern GtkWidget *remove_all_files_button;
 
 extern gint split_file_mode;
@@ -123,16 +140,19 @@ extern gint multiple_files_tree_number;
 //how many split files
 gint split_files = 0;
 
-//put the split file in the split_file tab
+//! move all options inside
+ui_state *ui = NULL;
+
+//! Add another file to the split_file tab
 void put_split_filename(const char *filename,int progress_data)
 {
-  gdk_threads_enter();
+  enter_threads();
 
-  if (!GTK_WIDGET_SENSITIVE(queue_files_button))
+  if (!gtk_widget_get_sensitive(queue_files_button))
   {
     gtk_widget_set_sensitive(queue_files_button, TRUE);
   }
-  if (!GTK_WIDGET_SENSITIVE(remove_all_files_button))
+  if (!gtk_widget_get_sensitive(remove_all_files_button))
   {
     gtk_widget_set_sensitive(remove_all_files_button,TRUE);
   }
@@ -151,10 +171,18 @@ void put_split_filename(const char *filename,int progress_data)
     fname_status = NULL;
   }
 
-  gdk_threads_leave();
+#ifdef __WIN32__
+  while (gtk_events_pending())
+  {
+	  gtk_main_iteration();
+  }
+  gdk_flush();
+#endif
+
+  exit_threads();
 }
 
-//changes the progress bar
+//!Allows to set the value shown by the progress bar
 void change_window_progress_bar(splt_progress *p_bar)
 {
   gchar progress_text[1024] = " ";
@@ -177,9 +205,9 @@ void change_window_progress_bar(splt_progress *p_bar)
       g_snprintf(progress_text,1023, _(" searching for sync errors..."));
       break;
     case SPLT_PROGRESS_SCAN_SILENCE:
-      g_snprintf(progress_text,2047,
-          _("S: %02d, Level: %.2f dB; scanning for silence..."),
-          p_bar->silence_found_tracks, p_bar->silence_db_level);
+      g_snprintf(progress_text,1023,
+		      _("S: %02d, Level: %.2f dB; scanning for silence..."),
+		      p_bar->silence_found_tracks, p_bar->silence_db_level);
       break;
     default:
       g_snprintf(progress_text,1023, " ");
@@ -188,7 +216,7 @@ void change_window_progress_bar(splt_progress *p_bar)
 
   gchar printed_value[1024] = { '\0' };
 
-  gdk_threads_enter();
+  enter_threads();
 
   gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(percent_progress_bar),
       p_bar->percent_progress);
@@ -198,19 +226,27 @@ void change_window_progress_bar(splt_progress *p_bar)
   gtk_progress_bar_set_text(GTK_PROGRESS_BAR(percent_progress_bar),
       printed_value);
 
-  gdk_threads_leave();
+#ifdef __WIN32__
+  while (gtk_events_pending())
+  {
+	  gtk_main_iteration();
+  }
+  gdk_flush();
+#endif
+
+  exit_threads();
 }
 
-//effective split of the file
+//! Split the file
 gpointer split_it(gpointer data)
 {
   gint confirmation = SPLT_OK;
   
-  gdk_threads_enter();
+  enter_threads();
 
   remove_all_split_rows();
 
-  gdk_threads_leave();
+  exit_threads();
  
   gint err = SPLT_OK;
 
@@ -227,17 +263,11 @@ gpointer split_it(gpointer data)
   gint split_mode =
     mp3splt_get_int_option(the_state, SPLT_OPT_SPLIT_MODE, &err);
 
-  gdk_threads_enter();
+  enter_threads();
   print_status_bar_confirmation(err);
   
-  //we put the splitpoints in the state only if the normal mode
-  if (split_mode == SPLT_OPTION_NORMAL_MODE)
-  {
-    put_splitpoints_in_the_state(the_state);
-  }
-
   gchar *format = strdup(gtk_entry_get_text(GTK_ENTRY(output_entry)));
-  gdk_threads_leave();
+  exit_threads();
 
   mp3splt_set_oformat(the_state, format, &err);
   if (format)
@@ -261,9 +291,15 @@ gpointer split_it(gpointer data)
   gint multiple_files_error = SPLT_FALSE;
   if (split_file_mode == FILE_MODE_SINGLE)
   {
-    gdk_threads_enter();
+    enter_threads();
+
+    if (split_mode == SPLT_OPTION_NORMAL_MODE)
+    {
+      put_splitpoints_in_the_state(the_state);
+    }
+
     print_processing_file(filename_to_split);
-    gdk_threads_leave();
+    exit_threads();
 
     mp3splt_set_filename_to_split(the_state, filename_to_split);
     confirmation = mp3splt_split(the_state);
@@ -272,7 +308,7 @@ gpointer split_it(gpointer data)
   {
     if (multiple_files_tree_number > 0)
     {
-      gdk_threads_enter();
+      enter_threads();
 
       gchar *filename = NULL;
       GtkTreeIter iter;
@@ -280,12 +316,17 @@ gpointer split_it(gpointer data)
       GtkTreeModel *model =
         gtk_tree_view_get_model(GTK_TREE_VIEW(multiple_files_tree));
 
-      gdk_threads_leave();
+      exit_threads();
 
       gint row_number = 0;
       while (row_number < multiple_files_tree_number)
       {
-        gdk_threads_enter();
+        enter_threads();
+
+        if (split_mode == SPLT_OPTION_NORMAL_MODE)
+        {
+          put_splitpoints_in_the_state(the_state);
+        }
 
         path = gtk_tree_path_new_from_indices(row_number ,-1);
         gtk_tree_model_get_iter(model, &iter, path);
@@ -294,7 +335,7 @@ gpointer split_it(gpointer data)
 
         print_processing_file(filename);
 
-        gdk_threads_leave();
+        exit_threads();
 
         mp3splt_set_filename_to_split(the_state, filename);
         confirmation = mp3splt_split(the_state);
@@ -312,7 +353,7 @@ gpointer split_it(gpointer data)
 
         row_number++;
 
-        gdk_threads_enter();
+        enter_threads();
 
         mp3splt_erase_all_tags(the_state, &err);
         print_status_bar_confirmation(err);
@@ -320,23 +361,24 @@ gpointer split_it(gpointer data)
         mp3splt_erase_all_splitpoints(the_state, &err);
         print_status_bar_confirmation(err);
 
-        gdk_threads_leave();
+        exit_threads();
       }
     }
     else
     {
       multiple_files_error = SPLT_TRUE;
 
-      gdk_threads_enter();
+      enter_threads();
       put_status_message(_(" error: no files found in multiple files mode"));
-      gdk_threads_leave();
+      exit_threads();
     }
   }
 
-  //reenable default output if necessary
+  /*! reenable default output if necessary
+   */
   mp3splt_set_int_option(the_state, SPLT_OPT_OUTPUT_FILENAMES, output_filenames);
   
-  gdk_threads_enter();
+  enter_threads();
 
   //we show infos about the split action
   print_status_bar_confirmation(confirmation);
@@ -359,12 +401,15 @@ gpointer split_it(gpointer data)
 
   we_are_splitting = FALSE;
 
-  gdk_threads_leave();
+  exit_threads();
  
   return NULL;
 }
 
-//handler for the SIGPIPE signal
+/*!handler for the SIGPIPE signal
+
+  This signal is issued by snackamp on close.
+ */
 void sigpipe_handler(gint sig)
 {
   if (player_is_running() && selected_player == PLAYER_SNACKAMP)
@@ -374,7 +419,7 @@ void sigpipe_handler(gint sig)
 }
 
 gboolean sigint_called = FALSE;
-//handler for the SIGINT signal
+//!handler for the SIGINT signal
 void sigint_handler(gint sig)
 {
   if (!sigint_called)
@@ -385,7 +430,7 @@ void sigint_handler(gint sig)
   }
 }
 
-//prints a message from the library
+//!prints a message from the library
 void put_message_from_library(const char *message, splt_message_type mess_type)
 {
   gchar *mess = g_strdup(message);
@@ -400,16 +445,75 @@ void put_message_from_library(const char *message, splt_message_type mess_type)
         mess[i] = ' ';
       }
     }
-    gdk_threads_enter();
+    enter_threads();
+
     put_status_message_with_type(mess, mess_type);
-    gdk_threads_leave();
+
+#ifdef __WIN32__
+  while (gtk_events_pending())
+  {
+	  gtk_main_iteration();
+  }
+  gdk_flush();
+#endif
+
+    exit_threads();
     g_free(mess);
     mess = NULL;
   }
 }
 
+GThread *create_thread(GThreadFunc func, gpointer data,
+		gboolean joinable, GError **error)
+{
+/*#ifdef __WIN32__
+	func(data);
+	return NULL;
+	return g_thread_create(func, data, joinable, error);
+#else*/
+	return g_thread_create(func, data, joinable, error);
+//#endif
+}
+
+void enter_threads()
+{
+	gdk_threads_enter();
+}
+
+void exit_threads()
+{
+	gdk_threads_leave();
+}
+
+/*! The traditional C main function
+
+\todo 
+ - Handle the case that more than one input file is specified at the 
+   command line. Until now we just open the first one of the specified 
+   files which on windows is basically what notepad does.\n
+   And decide what to do in this case: 
+   - Going into the multiple files mode will mean that our functionality
+     is enabled if several files are opened at once in Windows
+   - And opening a separate instance of our program would mean that
+     windows and nautilus behaviour are consistent (nautilus seems to
+     open every file separately) but - does this really make sense?
+ - Handle the case that the specified inputfile is a playlist file
+ - Set the full path to the file to make sure that the player will find 
+   it even if we are called in a different directory than the file is in
+   and stuff.
+ - Gstreamer needs a fully qualified path to the audio file in order to 
+   be able to play it back. Don't know why. But what I know is that on
+   solaris realpath() may return a relative filename. And there might
+   be an old system around that does not malloc() memory for a pathname
+   if the pathname we give to it is 0 => find a solution that works 
+   everywhere.
+ */
 gint main(gint argc, gchar *argv[], gchar **envp)
 {
+  ui = ui_state_new();
+
+  int OptionChar;
+
   //init threads
   g_thread_init(NULL);
   gdk_threads_init();
@@ -443,8 +547,8 @@ gint main(gint argc, gchar *argv[], gchar **envp)
   gchar *end = strrchr(mp3splt_uninstall_file, SPLT_DIRCHAR);
   if (end) { *end = '\0'; }
 
-  gchar *executable = strdup(argv[0]);
   gchar *executable_dir = NULL;
+  gchar *executable = strdup(argv[0]);
 
   end = strrchr(executable, SPLT_DIRCHAR);
   if (end)
@@ -460,44 +564,61 @@ gint main(gint argc, gchar *argv[], gchar **envp)
     }
   }
 
-  if (executable_dir != NULL)
-  {
-    gint translation_dir_length = strlen(executable_dir) + 30;
-    gchar *translation_dir = malloc(sizeof(gchar) * translation_dir_length);
-    if (translation_dir)
-    {
-      g_snprintf(translation_dir,translation_dir_length,
-          "%s%ctranslations",executable_dir,SPLT_DIRCHAR);
-
-      bindtextdomain(MP3SPLT_LIB_GETTEXT_DOMAIN, translation_dir);
-      bindtextdomain("mp3splt-gtk", translation_dir);
-
-      if (translation_dir)
-      {
-        free(translation_dir);
-        translation_dir = NULL;
-      }
-    }
-  }
-  else
-  {
-    bindtextdomain(MP3SPLT_LIB_GETTEXT_DOMAIN, "translations");
-    bindtextdomain("mp3splt-gtk", "translations");
-  }
+  bindtextdomain(MP3SPLT_LIB_GETTEXT_DOMAIN, "translations");
+  bindtextdomain("mp3splt-gtk", "translations");
 
 #else
-  bindtextdomain ("mp3splt-gtk", LOCALEDIR);
+  bindtextdomain("mp3splt-gtk", LOCALEDIR);
 #endif
 
-  bind_textdomain_codeset ("mp3splt-gtk", "UTF-8");
+  bind_textdomain_codeset("mp3splt-gtk", "UTF-8");
  
+  // Allow the gtk to parse all gtk arguments from the command 
+  // line first
   gtk_init(&argc, &argv);
   
-  //we initialise the splitpoints array
+  // Now pass all remaining arguments to getopt.
+  opterr = 0;
+  
+  while ((OptionChar = getopt (argc, argv, "d:")) != -1)
+    switch (OptionChar)
+      {
+      case 'd':
+	fprintf (stderr, _("Trying to set the output directory to %s.\n"), optarg);
+	outputdirectory_set((gchar *)optarg);
+#ifdef __WIN32__
+	mkdir(optarg);
+#else
+	mkdir(optarg, 0777);
+#endif
+	if(!check_if_dir((guchar *)optarg))
+	  {
+	    fprintf(stderr,_("Error: The specified output directory is inaccessible!\n"));
+	    exit(-1);
+	  }
+	break;
+      case '?':
+	if (optopt == 'd')
+	  fprintf (stderr, _("Option -%c requires an argument.\n"), optopt);
+	else if (isprint (optopt))
+	  fprintf (stderr, _("Unknown option `-%c'.\n"), optopt);
+	else
+	  fprintf (stderr,
+		   _("Unknown option character `\\x%x'.\n"),
+		   optopt);
+	return 1;
+      default:
+	abort ();
+      }
+  
+  // If we have a filename at the command line is checked after the
+  // GUI is up.
+
+  //We initialise the splitpoints array
   splitpoints = g_array_new(FALSE, FALSE, sizeof (Split_point));
  
-  //checks if preferences file exists
-  //and if it does not, it creates it
+  //check if preferences file exists
+  //and if it does not create it
   check_pref_file();
  
   mp3splt_set_progress_function(the_state,change_window_progress_bar);
@@ -505,6 +626,8 @@ gint main(gint argc, gchar *argv[], gchar **envp)
   mp3splt_set_message_function(the_state, put_message_from_library);
 
   mp3splt_set_int_option(the_state, SPLT_OPT_DEBUG_MODE, SPLT_FALSE);
+  mp3splt_set_int_option(the_state,
+      SPLT_OPT_SET_FILE_FROM_CUE_IF_FILE_TAG_FOUND, SPLT_TRUE);
 
   //add special directory search for plugins on Windows
 #ifdef __WIN32__
@@ -512,16 +635,10 @@ gint main(gint argc, gchar *argv[], gchar **envp)
   {
     if (executable[0] != '\0')
     {
-      g_setenv("GST_PLUGIN_PATH",executable,TRUE);
+      g_setenv("GST_PLUGIN_PATH", ".\\", TRUE);
       mp3splt_append_plugins_scan_dir(the_state, executable);
+      _chdir(executable);
     }
-    free(executable);
-    executable = NULL;
-  }
-
-  if (mp3splt_uninstall_file[0] != '\0')
-  {
-    mp3splt_append_plugins_scan_dir(the_state, mp3splt_uninstall_file);
   }
 #endif
 
@@ -532,10 +649,38 @@ gint main(gint argc, gchar *argv[], gchar **envp)
   {
     print_status_bar_confirmation(error);
   }
-  
+
+  // Now let's see if we found a filename at the command line.
+  if (optind != argc) 
+    {
+      if(!check_if_file((guchar *)argv[optind]))
+	{
+	  fprintf (stderr,
+		   _("Cannot open input file %s\n"),
+		   argv[optind]);
+	return 1;
+	}
+
+#ifndef __WIN32__
+      // If we start the player it will find a file with a relative
+      // pathname. But if the player is already running it might
+      // need an absolute path.
+      char *inputfilename=realpath(argv[optind],NULL);
+      handle_import(inputfilename);
+      free(inputfilename);
+#else
+      handle_import(argv[optind]);
+#endif
+    }
+
   gdk_threads_enter();
   gtk_main();
-  gdk_threads_leave();
+  exit_threads();
+
+  mp3splt_free_state(the_state, &error);
+
+  ui_state_free(ui);
   
   return 0;
 }
+
