@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -36,6 +36,18 @@
  *
  *********************************************************/
 
+#ifndef _MP3SPLT_GTK_H
+#define _MP3SPLT_GTK_H
+
 void put_options_from_preferences();
 gpointer split_it(gpointer data);
 void sigpipe_handler(gint sig);
+
+GThread *create_thread(GThreadFunc func, gpointer data,
+		gboolean joinable, GError **error);
+void enter_threads();
+void exit_threads();
+
+#define MP3SPLT_GTK_DATE "14/11/11"
+
+#endif
