@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -29,11 +29,12 @@
  *
  *********************************************************/
 
-/**********************************************************
- * Filename: multiple_files.c
- *
- * this file is for the multiple files management
+/*!********************************************************
+ * \file 
+ * Batch processing internals
  *
+ * this file is for management for the the multiple files
+ * mode that currently allows only for batch processing.
  *********************************************************/
 
 #include <gtk/gtk.h>
@@ -42,8 +43,11 @@
 
 #include "multiple_files.h"
 #include "main_win.h"
+#include "ui_manager.h"
+#include "widgets_helper.h"
 
 extern splt_state *the_state;
+extern ui_state *ui;
 
 GtkWidget *multiple_files_tree = NULL;
 gint multiple_files_tree_number = 0;
@@ -53,6 +57,7 @@ GtkWidget *multiple_files_remove_all_files_button = NULL;
 
 #define MY_GTK_RESPONSE 200
 
+//!Create the model for the batch processing file list
 GtkTreeModel *create_multiple_files_model()
 {
   GtkListStore *model;
@@ -80,7 +85,7 @@ void create_multiple_files_columns(GtkTreeView *tree_view)
   GtkCellRendererText *renderer =
     GTK_CELL_RENDERER_TEXT(gtk_cell_renderer_text_new());
   GtkTreeViewColumn *filename_column = gtk_tree_view_column_new_with_attributes 
-    ("Complete filename", GTK_CELL_RENDERER(renderer),
+    (_("Complete filename"), GTK_CELL_RENDERER(renderer),
      "text", MULTIPLE_COL_FILENAME, NULL);
   gtk_tree_view_insert_column(GTK_TREE_VIEW(tree_view),
       GTK_TREE_VIEW_COLUMN(filename_column),MULTIPLE_COL_FILENAME);
@@ -101,13 +106,15 @@ void multiple_files_add_button_event(GtkWidget *widget, gpointer data)
   GtkWidget *file_chooser;
   GtkWidget *our_filter;
  
-  file_chooser = gtk_file_chooser_dialog_new (_("Choose file or directory"),
+  file_chooser = gtk_file_chooser_dialog_new(_("Choose file or directory"),
                                               NULL,
                                               GTK_FILE_CHOOSER_ACTION_OPEN,
                                               GTK_STOCK_CANCEL,
                                               GTK_RESPONSE_CANCEL,
                                               NULL);
 
+  wh_set_browser_directory_handler(ui, file_chooser);
+
   GtkWidget *button = gtk_dialog_add_button(GTK_DIALOG(file_chooser),
       GTK_STOCK_ADD, MY_GTK_RESPONSE);
   gtk_button_set_use_stock(GTK_BUTTON(button), TRUE);
@@ -120,19 +127,23 @@ void multiple_files_add_button_event(GtkWidget *widget, gpointer data)
  
   //mp3 & ogg filter
   our_filter = (GtkWidget *)gtk_file_filter_new();
-  gtk_file_filter_set_name (GTK_FILE_FILTER(our_filter), _("mp3 and ogg files(*.mp3 *.ogg)"));
+  gtk_file_filter_set_name (GTK_FILE_FILTER(our_filter), _("mp3 and ogg files (*.mp3 *.ogg)"));
   gtk_file_filter_add_pattern(GTK_FILE_FILTER(our_filter), "*.mp3");
+  gtk_file_filter_add_pattern(GTK_FILE_FILTER(our_filter), "*.MP3");
   gtk_file_filter_add_pattern(GTK_FILE_FILTER(our_filter), "*.ogg");
+  gtk_file_filter_add_pattern(GTK_FILE_FILTER(our_filter), "*.OGG");
   gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(file_chooser), GTK_FILE_FILTER(our_filter));
   //mp3 filter
   our_filter = (GtkWidget *)gtk_file_filter_new();
-  gtk_file_filter_set_name (GTK_FILE_FILTER(our_filter), _("mp3 files(*.mp3)"));
+  gtk_file_filter_set_name (GTK_FILE_FILTER(our_filter), _("mp3 files (*.mp3)"));
   gtk_file_filter_add_pattern(GTK_FILE_FILTER(our_filter), "*.mp3");
+  gtk_file_filter_add_pattern(GTK_FILE_FILTER(our_filter), "*.MP3");
   gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(file_chooser), GTK_FILE_FILTER(our_filter));
   //ogg filter
   our_filter = (GtkWidget *)gtk_file_filter_new();
-  gtk_file_filter_set_name (GTK_FILE_FILTER(our_filter), _("ogg files(*.ogg)"));
+  gtk_file_filter_set_name (GTK_FILE_FILTER(our_filter), _("ogg files (*.ogg)"));
   gtk_file_filter_add_pattern(GTK_FILE_FILTER(our_filter), "*.ogg");
+  gtk_file_filter_add_pattern(GTK_FILE_FILTER(our_filter), "*.OGG");
   gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(file_chooser), GTK_FILE_FILTER(our_filter));
 
   //all files filter
@@ -207,7 +218,6 @@ void multiple_files_remove_button_event(GtkWidget *widget, gpointer data)
 {
   GtkTreeIter iter;
   GtkTreeModel *model;
-  gint i;
   GtkTreePath *path;
   GList *selected_list = NULL;
   GList *current_element = NULL;
@@ -225,7 +235,6 @@ void multiple_files_remove_button_event(GtkWidget *widget, gpointer data)
     //get the last element
     current_element = g_list_last(selected_list);
     path = current_element->data;
-    i = gtk_tree_path_get_indices(path)[0];
     //get the iter correspondig to the path
     gtk_tree_model_get_iter(model, &iter, path);
     gtk_tree_model_get(model, &iter, MULTIPLE_COL_FILENAME, &filename, -1);
