@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright (c) 2005-2010 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2011 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
  *
@@ -35,7 +35,12 @@
  *
  *********************************************************/
 
-//time structure
+#ifndef _PLAYER_TAB_H
+#define _PLAYER_TAB_H
+
+#define ICON_EXT ".svg"
+
+//!time structure
 typedef struct
 {
   long time;
@@ -152,14 +157,14 @@ gfloat pixels_to_time(gfloat width,
                       gint pixels);
 gint get_draw_line_position(gint width,
                             gfloat time);
-void draw_motif(GtkWidget *da,GdkGC *gc,
+void draw_motif(GtkWidget *da,cairo_t *gc,
                 gint ylimit,gint x,gint model);
 void draw_marks(gint time_interval,
                 gint left_mark,gint right_mark,
-                gint ylimit, GtkWidget *da, GdkGC *gc);
+                gint ylimit, GtkWidget *da, cairo_t *gc);
 //motif for splitpoints
 //draw is false if we draw the splitpoint we move
-void draw_motif_splitpoints(GtkWidget *da, GdkGC *gc,
+void draw_motif_splitpoints(GtkWidget *da, cairo_t *gc,
                             gint x,gint draw,
                             gint current_point_hundr_secs,
                             gboolean move,
@@ -167,7 +172,7 @@ void draw_motif_splitpoints(GtkWidget *da, GdkGC *gc,
 void draw_splitpoints(gint left_mark,
                       gint right_mark,
                       GtkWidget *da,
-                      GdkGC *gc);
+                      cairo_t *gc);
 gboolean da_expose_event (GtkWidget      *da,
                           GdkEventExpose *event,
                           gpointer       data);
@@ -203,3 +208,10 @@ void show_connect_button();
 void hide_disconnect_button();
 void show_disconnect_button();
 
+void inputfilename_set(const gchar *filename);
+gchar *inputfilename_get();
+
+void build_svg_path(GString *imagefile, gchar *svg_filename);
+
+#endif
+
