@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -29,6 +29,15 @@
  *
  *********************************************************/
 
+/*!********************************************************
+ * \file 
+ * Save and read preferences
+ *
+ * This file contains the functions to save the preferences
+ * on the hard disk and to read them again at the next 
+ * start of the program.
+ ********************************************************/
+
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -40,9 +49,12 @@
 #include <libmp3splt/mp3splt.h>
 
 #include "player.h"
+#include "preferences_tab.h"
 #include "special_split.h"
+#include "combo_helper.h"
+#include "radio_helper.h"
+#include "ui_manager.h"
 
-extern GtkWidget *directory_entry;
 extern GtkWidget *player_combo_box;
 extern gint selected_player;
 extern GList *player_pref_list;
@@ -50,10 +62,9 @@ extern GtkWidget *radio_button;
 
 extern GtkWidget *file_mode_radio_button;
 
-extern GtkWidget *entry;
-
 extern GtkWidget *frame_mode;
 extern GtkWidget *adjust_mode;
+extern GtkWidget *names_from_filename;
 extern GtkWidget *spinner_adjust_gap;
 extern GtkWidget *spinner_adjust_offset;
 extern GtkWidget *spinner_adjust_threshold;
@@ -69,11 +80,26 @@ extern GtkWidget *tags_version_radio;
 
 extern splt_state *the_state;
 
-//filename returned must be freed after
-//that functions also checks if we have a directory .mp3splt-gtk and
-//if not it creates it. if we have a file .mp3splt-gtk, it makes a
-//backup and then creates the directory
-//result must be freed!!!!
+extern GtkWidget *replace_underscore_by_space_check_box;
+extern GtkComboBox *artist_text_properties_combo;
+extern GtkComboBox *album_text_properties_combo;
+extern GtkComboBox *title_text_properties_combo;
+extern GtkComboBox *comment_text_properties_combo;
+extern GtkComboBox *genre_combo;
+extern GtkWidget *comment_tag_entry;
+extern GtkWidget *regex_entry;
+extern GtkWidget *test_regex_fname_entry;
+
+extern ui_state *ui;
+
+/*! Get the name of the preferences file.
+
+\attention filename returned must be freed after
+that functions also checks if we have a directory .mp3splt-gtk and
+if not it creates it. if we have a file .mp3splt-gtk, it makes a
+backup and then creates the directory
+result must be freed!!!!
+*/
 gchar *get_preferences_filename()
 {
   gchar mp3splt_dir[14] = ".mp3splt-gtk";
@@ -151,6 +177,8 @@ gchar *get_preferences_filename()
   return filename;
 }
 
+/*! \brief Read the preferences from the preferences file.
+ */
 void load_preferences()
 {
   GKeyFile *key_file = g_key_file_new();
@@ -173,11 +201,13 @@ void load_preferences()
 
   //0 = german, 1 = french, 2 = english
   gint list_number = 2;
-  if (g_string_equal(lang,g_string_new("de")))
+  if (g_string_equal(lang,g_string_new("de")) ||
+      g_string_equal(lang,g_string_new("de_DE")))
   {
     list_number = 0;
   }
-  else if (g_string_equal(lang, g_string_new("fr")))
+  else if (g_string_equal(lang, g_string_new("fr")) ||
+      g_string_equal(lang, g_string_new("fr_FR")))
   {
     list_number = 1;
   }
@@ -194,30 +224,25 @@ void load_preferences()
   lang = NULL;
 #endif
 
-  //output_path
-  gchar *save_path = g_key_file_get_string(key_file, "split", "save_path", NULL);
-  if (save_path != NULL)
+  // If outputdirectory_get()!=NULL the path where to output the split file
+  // to has been set from command line
+  if(outputdirectory_get()==NULL)
   {
-    gtk_entry_set_text(GTK_ENTRY(directory_entry), save_path);
-  }
-  g_free(save_path);
-  save_path = NULL;
-
-  //selected player
-  gint item = g_key_file_get_integer(key_file, "player", "default_player",NULL);
-  //if its the first time we load preferences
-  gint i;
-  for(i = 0; i < 4; i++)
-  {
-    if (item == GPOINTER_TO_INT(g_list_nth_data(player_pref_list, i)))
+    // No output_path from command-line => get the path from the preferences
+    gchar *save_path = g_key_file_get_string(key_file, "split", "save_path", NULL);
     {
-      selected_player = GPOINTER_TO_INT(g_list_nth_data(player_pref_list, i));
-      goto jump_near;
+      if (save_path != NULL)
+      {
+        outputdirectory_set(save_path);
+      }
+      g_free(save_path);
+      save_path = NULL;
     }
   }
 
-jump_near:
-  gtk_combo_box_set_active(GTK_COMBO_BOX(player_combo_box), i);
+  //selected player
+  gint item = g_key_file_get_integer(key_file, "player", "default_player",NULL);
+  ch_set_active_value(GTK_COMBO_BOX(player_combo_box), item);
 
   //frame mode
   item = g_key_file_get_boolean(key_file, "split", "frame_mode", NULL);
@@ -241,6 +266,16 @@ jump_near:
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(adjust_mode),FALSE);
   }
 
+  item = g_key_file_get_boolean(key_file, "output", "splitpoint_names_from_filename", NULL);
+  if (item)
+  {
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(names_from_filename),TRUE);
+  }
+  else
+  {
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(names_from_filename),FALSE);
+  }
+
   //adjust threshold
   gfloat item2;
   item = g_key_file_get_integer(key_file, "split", "adjust_threshold", NULL);  
@@ -257,18 +292,110 @@ jump_near:
 
   //tags options
   gint tag_pref_file = g_key_file_get_integer(key_file, "split", "tags", NULL);
-  GSList *tags_radio_button_list = 
-    gtk_radio_button_get_group(GTK_RADIO_BUTTON(tags_radio));
-  GtkWidget *the_selection = 
-    (GtkWidget *)g_slist_nth_data(tags_radio_button_list, tag_pref_file);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(the_selection), TRUE);
+  GtkWidget *radio = rh_get_radio_from_value(tags_radio, tag_pref_file);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
+
+  //replace underscores by spaces
+  item = g_key_file_get_boolean(key_file, "split", "replace_underscore_by_space", NULL);
+  if (item)
+  {
+    gtk_toggle_button_set_active(
+        GTK_TOGGLE_BUTTON(replace_underscore_by_space_check_box), TRUE);
+  }
+  else
+  {
+    gtk_toggle_button_set_active(
+        GTK_TOGGLE_BUTTON(replace_underscore_by_space_check_box), FALSE);
+  }
+
+  //artist text properties
+  item = g_key_file_get_integer(key_file, "split", "artist_text_properties",NULL);
+  if (item)
+  {
+    ch_set_active_value(artist_text_properties_combo, item);
+  }
+  else
+  {
+    ch_set_active_value(artist_text_properties_combo, SPLT_NO_CONVERSION);
+  }
+  //album text properties
+  item = g_key_file_get_integer(key_file, "split", "album_text_properties",NULL);
+  if (item)
+  {
+    ch_set_active_value(album_text_properties_combo, item);
+  }
+  else
+  {
+    ch_set_active_value(album_text_properties_combo, SPLT_NO_CONVERSION);
+  }
+  //title text properties
+  item = g_key_file_get_integer(key_file, "split", "title_text_properties",NULL);
+  if (item)
+  {
+    ch_set_active_value(title_text_properties_combo, item);
+  }
+  else
+  {
+    ch_set_active_value(title_text_properties_combo, SPLT_NO_CONVERSION);
+  }
+  //comment text properties
+  item = g_key_file_get_integer(key_file, "split", "comment_text_properties",NULL);
+  if (item)
+  {
+    ch_set_active_value(comment_text_properties_combo, item);
+  }
+  else
+  {
+    ch_set_active_value(comment_text_properties_combo, SPLT_NO_CONVERSION);
+  }
+
+  //genre
+  gchar *default_genre = g_key_file_get_string(key_file, "split", "genre", NULL);
+  if (default_genre)
+  {
+    ch_set_active_str_value(genre_combo, default_genre);
+    g_free(default_genre);
+    default_genre = NULL;
+  }
+  else
+  {
+    ch_set_active_str_value(genre_combo, SPLT_UNDEFINED_GENRE);
+  }
+
+  //default comment tag
+  gchar *default_comment_tag = g_key_file_get_string(key_file, "split", "default_comment_tag", NULL);
+  if (default_comment_tag)
+  {
+    gtk_entry_set_text(GTK_ENTRY(comment_tag_entry), default_comment_tag);
+    g_free(default_comment_tag);
+    default_comment_tag = NULL;
+  }
+
+  //regexp to parse filename into tags
+  gchar *tags_from_fname_regex =
+    g_key_file_get_string(key_file, "split", "tags_from_filename_regex", NULL);
+  if (tags_from_fname_regex)
+  {
+    gtk_entry_set_text(GTK_ENTRY(regex_entry), tags_from_fname_regex);
+    g_free(tags_from_fname_regex);
+    tags_from_fname_regex = NULL;
+  }
+
+  gchar *test_regex_fname = 
+    g_key_file_get_string(key_file, "split", "test_regex_fname", NULL);
+  if (test_regex_fname)
+  {
+    gtk_entry_set_text(GTK_ENTRY(test_regex_fname_entry), test_regex_fname);
+    g_free(test_regex_fname);
+    test_regex_fname = NULL;
+  }
 
   //tags version
   tag_pref_file = g_key_file_get_integer(key_file, "split", "tags_version", NULL);
 
   GSList *tags_version_radio_button_list = 
     gtk_radio_button_get_group(GTK_RADIO_BUTTON(tags_version_radio));
-  the_selection = 
+  GtkWidget *the_selection = 
     (GtkWidget *)g_slist_nth_data(tags_version_radio_button_list, tag_pref_file);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_selection), TRUE);
 
@@ -288,9 +415,12 @@ jump_near:
 
   //output format
   gchar *output_format = g_key_file_get_string(key_file, "output", "output_format", NULL);
-  gtk_entry_set_text(GTK_ENTRY(output_entry), output_format);
-  g_free(output_format);
-  output_format = NULL;
+  if (output_format)
+  {
+    gtk_entry_set_text(GTK_ENTRY(output_entry), output_format);
+    g_free(output_format);
+    output_format = NULL;
+  }
 
   //create directories if needed
   item = g_key_file_get_boolean(key_file, "output", "create_dirs_if_needed", NULL);
@@ -326,12 +456,36 @@ jump_near:
       "split_mode_equal_time_tracks", NULL);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinner_equal_tracks), equal_tracks);
 
+  gint root_x = g_key_file_get_integer(key_file, "gui", "root_x_position", NULL);
+  gint root_y = g_key_file_get_integer(key_file, "gui", "root_y_position", NULL);
+  if (root_x && root_y)
+  {
+    ui_set_main_win_position(ui, root_x, root_y);
+  }
+
+  gint width = g_key_file_get_integer(key_file, "gui", "width", NULL);
+  gint height = g_key_file_get_integer(key_file, "gui", "height", NULL);
+  if (width && height)
+  {
+    ui_set_main_win_size(ui, width, height);
+  }
+
+  gchar *browser_directory =
+    g_key_file_get_string(key_file, "gui", "browser_directory", NULL);
+  if (browser_directory)
+  {
+    ui_set_browser_directory(ui, browser_directory);
+    g_free(browser_directory);
+  }
+
   g_key_file_free(key_file);
   key_file = NULL;
 }
 
-//writes a default configuration file
-//or writes good values on an ugly existing configuration file
+/* \brief writes a default configuration file
+
+Also is used to write good values on a bad existing configuration file
+*/
 void write_default_preferences_file()
 {
   gchar *filename = get_preferences_filename();
@@ -358,11 +512,14 @@ void write_default_preferences_file()
 
     if((!g_string_equal(lang_char,g_string_new("en")))
         &&(!g_string_equal(lang_char, g_string_new("fr")))
-        &&(!g_string_equal(lang_char, g_string_new("de"))))
+        &&(!g_string_equal(lang_char, g_string_new("fr_FR")))
+        &&(!g_string_equal(lang_char, g_string_new("de")))
+        &&(!g_string_equal(lang_char, g_string_new("de_DE")))
+        )
     {
       g_key_file_set_string(my_key_file, "general", "language", "en");
       g_key_file_set_comment(my_key_file, "general", "language",
-          "\n language of the gui: en = english, fr = french, de = german",
+          "\n language of the gui: en = english, fr_FR = french, de_DE = german",
           NULL);
     }
 
@@ -451,7 +608,7 @@ void write_default_preferences_file()
   {
     g_key_file_set_integer(my_key_file, "split", "tags", 1);
     g_key_file_set_comment(my_key_file, "split", "tags",
-        "\n 0 - No tags, 1 - Default tags, 2 - Original tags", NULL);
+        "\n 0 - No tags, 1 - Default tags, 2 - Original tags, 3 - Tags from filename", NULL);
   }
 
   //tags version
@@ -500,7 +657,7 @@ void write_default_preferences_file()
         SPLT_DEFAULT_OUTPUT);
     g_key_file_set_comment (my_key_file, "output", "output_format",
         "\n the output format, contains @a,"
-        "@b, @p, @t and @n, see the program for"
+        "@b, @g, @p, @t and @n, see the program for"
         " more details",
         NULL);
   }
@@ -607,8 +764,10 @@ void write_default_preferences_file()
   g_key_file_free(my_key_file);
 }
 
-//checks if preferences file exists
-//and if it does not, create it
+/*!\brief Create a preferences file --- if needed.
+
+checks if preferences file exists and if it does not, create it
+*/
 void check_pref_file()
 {
   //used to see if the file exists
@@ -642,7 +801,7 @@ void check_pref_file()
   write_default_preferences_file();
 }
 
-//sets the language, loaded only at start
+//!sets the language, loaded only at start
 void set_language()
 {
   GKeyFile *key_file = g_key_file_new();
