@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -29,71 +29,106 @@
  *
  *********************************************************/
 
-/**********************************************************
- * Filename: preferences_tab.c
+/*!********************************************************
+ * \file 
+ * The preferences tab
  *
- * this file is for the preferences tab, where we choose the preferences.
- *
- *********************************************************/
+ * this file contains the code for the preferences tab where 
+ * the preferences can be chosen.
+ ********************************************************/
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <string.h>
+
 #include <libmp3splt/mp3splt.h>
 
+#include "preferences_tab.h"
 #include "player.h"
 #include "util.h"
 #include "player_tab.h"
 #include "utilities.h"
 #include "main_win.h"
 #include "preferences_manager.h"
+#include "widgets_helper.h"
+#include "combo_helper.h"
+#include "radio_helper.h"
+#include "options_manager.h"
+#include "ui_manager.h"
+#include "widgets_helper.h"
 
-/* split preferences for choosing directory */
-//directory entry
+/*! The name of the output directory.
+  
+  Can be accessed by void outputdirectory_set() and 
+  outputdirectory_get().
+ */
+GString *outputdirname = NULL;
+
+//! The textbox that shows the name of the output directory
 GtkWidget *directory_entry = NULL;
 
-//output for the cddb,cue and freedb file output
+//!output for the cddb,cue and freedb file output
 GtkWidget *output_entry = NULL;
 GtkWidget *output_label = NULL;
 
-//if we have selected a correct file
-gint incorrect_selected_dir = FALSE;
-
-//choose the player box
+//!choose the player box
 GtkWidget *player_combo_box = NULL;
 
-//list where we stock the preferences combo box content
+//!list where we stock the preferences combo box content
 GList *player_pref_list = NULL;
+GList *text_options_list = NULL;
 //selected player
 gint selected_player = PLAYER_GSTREAMER;
 
-//the language radio button
+//!the language radio button
 GtkWidget *radio_button = NULL;
 
-//radio button for choosing default or custom output options
+//!radio button for choosing default or custom output options
 GtkWidget *radio_output = NULL;
 
-//radio button for tags options
+//!radio button for tags options
 GtkWidget *tags_radio = NULL;
 GtkWidget *tags_version_radio = NULL;
 
 //split options
-//frame mode option
+//!frame mode option
 GtkWidget *frame_mode = NULL;
-//auto-adjust option
+//!auto-adjust option
 GtkWidget *adjust_mode = NULL;
+// when ticked, name for split tag derived from filename
+GtkWidget *names_from_filename = NULL;
 
 GtkWidget *create_dirs_from_output_files = NULL;
 
-//adjust mode parameters
+/*!defgroup modeparameters adjust mode parameters
+@{
+*/
 GtkWidget *spinner_adjust_gap = NULL;
 GtkWidget *gap_label = NULL;
 GtkWidget *spinner_adjust_offset = NULL;
 GtkWidget *offset_label = NULL;
 GtkWidget *spinner_adjust_threshold = NULL;
 GtkWidget *threshold_label = NULL;
+//@}
+
+/*!defgroup options for tags from filename
+@{
+*/
+GtkWidget *replace_underscore_by_space_check_box = NULL;
+GtkComboBox *artist_text_properties_combo = NULL;
+GtkComboBox *album_text_properties_combo = NULL;
+GtkComboBox *title_text_properties_combo = NULL;
+GtkComboBox *comment_text_properties_combo = NULL;
+GtkComboBox *genre_combo = NULL;
+GtkWidget *comment_tag_entry = NULL;
+GtkWidget *regex_entry = NULL;
+GtkWidget *test_regex_fname_entry = NULL;
+GtkWidget *sample_result_label = NULL;
+
+GtkWidget *extract_tags_box = NULL;
+//@}
 
 extern GtkWidget *player_box;
 extern GtkWidget *queue_files_button;
@@ -103,8 +138,20 @@ extern gint split_file_mode;
 extern GtkWidget *spinner_time;
 extern GtkWidget *spinner_equal_tracks;
 
-//returns the selected language
-//must be free() after
+extern gint file_browsed;
+
+static GtkWidget *create_extract_tags_from_filename_options_box();
+static GtkWidget *create_test_regex_table();
+
+extern void clear_current_description(void);
+extern void copy_filename_to_current_description(const gchar *fname);
+
+extern ui_state *ui;
+
+/*!Returns the selected language
+
+must be free() the result after using it.
+*/
 GString *get_checked_language()
 {
   GSList *radio_button_list;
@@ -115,21 +162,21 @@ GString *get_checked_language()
   our_button = (GtkWidget *)g_slist_nth_data(radio_button_list, 0);
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(our_button)))
   {
-    return g_string_new("de");
+    return g_string_new("de_DE");
   }
   else 
   {
     our_button = (GtkWidget *)g_slist_nth_data(radio_button_list, 1);
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(our_button)))
     {
-      return g_string_new("fr");
+      return g_string_new("fr_FR");
     }
   }
 
   return g_string_new("en");
 }
 
-//returns the checked output radio box
+//!returns the checked output radio box
 gboolean get_checked_output_radio_box()
 {
   //get the radio buttons
@@ -152,33 +199,7 @@ gboolean get_checked_output_radio_box()
   return selected;
 }
 
-//returns the checked tags radio box
-gint get_checked_tags_radio_box()
-{
-  //get the radio buttons
-  GSList *radio_button_list;
-  radio_button_list = 
-    gtk_radio_button_get_group(GTK_RADIO_BUTTON(tags_radio));
-  //we check which bubble is checked
-  GtkToggleButton *test;
-  gint i, selected = 0;
-  //O = No tags
-  //1 = Default tags
-  //2 = Original file tags
-  for(i = 0; i<3;i++)
-    {
-      test = (GtkToggleButton *)
-        g_slist_nth_data(radio_button_list,i);
-      if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(test)))
-        {
-          selected = i;
-        }
-    }
-  
-  return selected;
-}
-
-//returns the checked tags radio box
+//!returns the checked tags radio box
 gint get_checked_tags_version_radio_box()
 {
   //get the radio buttons
@@ -204,7 +225,37 @@ gint get_checked_tags_version_radio_box()
   return selected;
 }
 
-//save preferences event
+//! Set the name of the output directory
+void outputdirectory_set(gchar *dirname)
+{
+  if(dirname!=NULL)
+    {
+      // Free the old string before allocating memory for the new one
+      if(outputdirname!=NULL)g_string_free(outputdirname,TRUE);
+      outputdirname=g_string_new(dirname);
+
+      // Update the text in the gui field displaying the output 
+      // directory - if this field is already there and thus can 
+      // be updated.
+      if(directory_entry!=NULL)
+	gtk_entry_set_text(GTK_ENTRY(directory_entry), dirname);
+    }
+}
+
+/*! Get the name of the output directory
+
+\return 
+ - The name of the output directory, if a directory is set.
+ - NULL, otherwise.
+*/
+gchar* outputdirectory_get()
+{
+  if(outputdirname!=NULL)
+    return(outputdirname->str);
+  else
+    return NULL;
+}
+
 void save_preferences(GtkWidget *widget, gpointer data)
 {
   gchar *filename = get_preferences_filename();
@@ -214,7 +265,7 @@ void save_preferences(GtkWidget *widget, gpointer data)
 
   //save_path
   g_key_file_set_string(my_key_file, "split", "save_path",
-      gtk_entry_get_text(GTK_ENTRY(directory_entry)));
+			outputdirectory_get());
   //default_player
   g_key_file_set_integer(my_key_file, "player", "default_player", selected_player);
 
@@ -245,6 +296,9 @@ void save_preferences(GtkWidget *widget, gpointer data)
   g_key_file_set_integer(my_key_file, "split", "adjust_gap",
       gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinner_adjust_gap)));
 
+  g_key_file_set_boolean(my_key_file, "output", "splitpoint_names_from_filename",
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(names_from_filename)));
+
   //output format
   g_key_file_set_string(my_key_file, "output", "output_format",
       gtk_entry_get_text(GTK_ENTRY(output_entry)));
@@ -255,8 +309,50 @@ void save_preferences(GtkWidget *widget, gpointer data)
       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(create_dirs_from_output_files)));
 
   //tags
-  g_key_file_set_integer(my_key_file, "split", "tags",
-      get_checked_tags_radio_box());
+  g_key_file_set_integer(my_key_file, "split", "tags", rh_get_active_value(tags_radio));
+
+  //replace underscores by space
+  g_key_file_set_boolean(my_key_file, "split", "replace_underscore_by_space",
+  gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(replace_underscore_by_space_check_box)));
+
+  //artist text properties
+  g_key_file_set_integer(my_key_file, "split", "artist_text_properties",
+      ch_get_active_value(artist_text_properties_combo));
+  //album text properties
+  g_key_file_set_integer(my_key_file, "split", "album_text_properties",
+      ch_get_active_value(album_text_properties_combo));
+  //title text properties
+  g_key_file_set_integer(my_key_file, "split", "title_text_properties",
+      ch_get_active_value(title_text_properties_combo));
+  //comment text properties
+  g_key_file_set_integer(my_key_file, "split", "comment_text_properties",
+      ch_get_active_value(comment_text_properties_combo));
+
+  //genre
+  gchar *genre_value = ch_get_active_str_value(genre_combo);
+  if (genre_value != NULL)
+  {
+    g_key_file_set_string(my_key_file, "split", "genre", genre_value);
+  }
+
+  const gchar *comment = gtk_entry_get_text(GTK_ENTRY(comment_tag_entry));
+  if (comment != NULL)
+  {
+    g_key_file_set_string(my_key_file, "split", "default_comment_tag", comment);
+  }
+
+  const gchar *regex_text = gtk_entry_get_text(GTK_ENTRY(regex_entry));
+  if (regex_text != NULL)
+  {
+    g_key_file_set_string(my_key_file, "split", "tags_from_filename_regex", regex_text);
+  }
+
+  const gchar *test_regex_fname = gtk_entry_get_text(GTK_ENTRY(test_regex_fname_entry));
+  if (test_regex_fname_entry != NULL)
+  {
+    g_key_file_set_string(my_key_file, "split", "test_regex_fname", test_regex_fname);
+  }
+
   //tags version
   g_key_file_set_integer(my_key_file, "split", "tags_version",
       get_checked_tags_version_radio_box());
@@ -274,7 +370,22 @@ void save_preferences(GtkWidget *widget, gpointer data)
   g_key_file_set_integer(my_key_file, "split", "split_mode_equal_time_tracks",
       gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spinner_equal_tracks)));
 
-  //our data
+  const ui_main_window *main_win = ui_get_main_window_infos(ui);
+  g_key_file_set_integer(my_key_file, "gui", "root_x_position", 
+      main_win->root_x_pos);
+  g_key_file_set_integer(my_key_file, "gui", "root_y_position", 
+      main_win->root_y_pos);
+  g_key_file_set_integer(my_key_file, "gui", "width", 
+      main_win->width);
+  g_key_file_set_integer(my_key_file, "gui", "height", 
+      main_win->height);
+
+  const char *browser_directory = ui_get_browser_directory(ui);
+  if (browser_directory != NULL)
+  {
+    g_key_file_set_string(my_key_file, "gui", "browser_directory", browser_directory);
+  }
+
   gchar *key_data = g_key_file_to_data(my_key_file, NULL, NULL);
 
   //we write to the preference file
@@ -295,7 +406,7 @@ void save_preferences(GtkWidget *widget, gpointer data)
   }
 }
 
-//creates a scrolled window
+//!creates a scrolled window
 GtkWidget *create_scrolled_window()
 {
   GtkWidget *scrolled_window;
@@ -307,7 +418,7 @@ GtkWidget *create_scrolled_window()
   return scrolled_window;
 }
 
-//cddb and cue output mode radio box event
+//!cddb and cue output mode radio box event
 void output_radio_box_event(GtkToggleButton *radio_b, gpointer data)
 {
   GtkWidget *output_label = (GtkWidget *)data;
@@ -333,6 +444,7 @@ void output_radio_box_event(GtkToggleButton *radio_b, gpointer data)
   save_preferences(NULL, NULL);
 }
 
+//! Create the "select language" box
 GtkWidget *create_language_box()
 {
   GtkWidget *radio_vbox = gtk_vbox_new (FALSE, 0);
@@ -354,10 +466,11 @@ GtkWidget *create_language_box()
       G_CALLBACK(save_preferences), NULL);
   gtk_box_pack_start(GTK_BOX(radio_vbox), radio_button, TRUE, TRUE, 0);
 
-  return set_title_and_get_vbox(radio_vbox,
+  return wh_set_title_and_get_vbox(radio_vbox,
       _("<b>Choose language (requires restart)</b>"));
 }
 
+//! Creates the language preferences page
 GtkWidget *create_pref_language_page()
 {
   GtkWidget *language_hbox = gtk_hbox_new(FALSE, 0);;
@@ -382,7 +495,7 @@ GtkWidget *create_pref_language_page()
   return language_hbox;
 }
 
-//events for browse dir button
+//! Events for browse dir button
 void browse_dir_button_event(GtkWidget *widget, gpointer data)
 {
   // file chooser
@@ -398,12 +511,14 @@ void browse_dir_button_event(GtkWidget *widget, gpointer data)
       GTK_RESPONSE_ACCEPT,
       NULL);
 
+  wh_set_browser_directory_handler(ui, dir_chooser);
+
   if (gtk_dialog_run(GTK_DIALOG(dir_chooser)) == GTK_RESPONSE_ACCEPT)
   {
     gchar *filename =
       gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dir_chooser));
 
-    gtk_entry_set_text(GTK_ENTRY(directory_entry), filename);
+    outputdirectory_set(filename);
 
     g_free (filename);
     filename = NULL;
@@ -415,7 +530,7 @@ void browse_dir_button_event(GtkWidget *widget, gpointer data)
   gtk_widget_destroy(dir_chooser);
 }
 
-//disables adjust parameters
+//!disables adjust parameters
 void disable_adjust_spinners()
 {
   gtk_widget_set_sensitive(spinner_adjust_threshold, FALSE);
@@ -426,7 +541,7 @@ void disable_adjust_spinners()
   gtk_widget_set_sensitive(gap_label, FALSE);
 }
 
-//enables adjust parameters
+//!enables adjust parameters
 void enable_adjust_spinners()
 {
   gtk_widget_set_sensitive(spinner_adjust_threshold, TRUE);
@@ -437,7 +552,7 @@ void enable_adjust_spinners()
   gtk_widget_set_sensitive(gap_label, TRUE);
 }
 
-//adjust event
+//!adjust event
 void adjust_event(GtkToggleButton *adjust_mode, gpointer user_data)
 {
   //if it is toggled
@@ -458,7 +573,7 @@ void adjust_event(GtkToggleButton *adjust_mode, gpointer user_data)
   save_preferences(NULL, NULL);
 }
 
-//frame mode event
+//!frame mode event
 void frame_event(GtkToggleButton *frame_mode, gpointer user_data)
 {
   if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(frame_mode)))
@@ -472,7 +587,32 @@ void frame_event(GtkToggleButton *frame_mode, gpointer user_data)
   save_preferences(NULL, NULL);
 }
 
-//action for the set default prefs button
+void splitpoints_from_filename_event(GtkToggleButton *frame_mode, gpointer user_data)
+{
+  gint splitpoints_from_filename = FALSE;
+
+  if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(names_from_filename)))
+  {
+    splitpoints_from_filename = FALSE;
+  }
+  else
+  {
+    splitpoints_from_filename = TRUE;
+  }
+
+  if (splitpoints_from_filename == TRUE && file_browsed == TRUE)
+  {
+    copy_filename_to_current_description(inputfilename_get());
+  }
+  else
+  {
+    clear_current_description();
+  }
+
+  save_preferences(NULL, NULL);
+}
+
+//!action for the set default prefs button
 void set_default_prefs_event(GtkWidget *widget, gpointer data)
 {
   //set frame mode inactive
@@ -486,25 +626,31 @@ void set_default_prefs_event(GtkWidget *widget, gpointer data)
                             SPLT_DEFAULT_PARAM_OFFSET);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinner_adjust_gap),
                             SPLT_DEFAULT_PARAM_GAP);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(names_from_filename), FALSE);
 
   save_preferences(NULL, NULL);
 }
 
-//events for the "set current song directory"
+//!events for the "set current song directory"
 void song_dir_button_event(GtkWidget *widget, gpointer data)
 {
-  gtk_entry_set_text(GTK_ENTRY(directory_entry), "");
-  save_preferences(NULL, NULL);
+    outputdirectory_set("");
+    save_preferences(NULL, NULL);
 }
 
+//!Creates the box the output directory can be choosen in
 GtkWidget *create_directory_box()
 {
   GtkWidget *dir_hbox = gtk_hbox_new(FALSE, 0);
   
   //directory entry
   directory_entry = gtk_entry_new();
-  gtk_entry_set_editable(GTK_ENTRY(directory_entry), FALSE);
+  gtk_editable_set_editable(GTK_EDITABLE(directory_entry), FALSE);
   gtk_box_pack_start(GTK_BOX(dir_hbox), directory_entry, TRUE, TRUE, 0);
+  // Put the right text into the text box containing the output directory
+  // name if this name was provided on command line
+  if(outputdirectory_get()!=NULL)
+    gtk_entry_set_text(GTK_ENTRY(directory_entry), outputdirectory_get());
   
   //browse dir button
   GtkWidget *browse_dir_button = (GtkWidget *)
@@ -521,13 +667,20 @@ GtkWidget *create_directory_box()
       G_CALLBACK(song_dir_button_event), NULL);
   gtk_box_pack_start(GTK_BOX(dir_hbox), song_dir_button, FALSE, FALSE, 0);
 
-  return set_title_and_get_vbox(dir_hbox, _("<b>Directory for split files</b>"));
+  return wh_set_title_and_get_vbox(dir_hbox, _("<b>Directory for split files</b>"));
 }
 
+//! Creates the box for split mode selection
 GtkWidget *create_split_options_box()
 {
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
 
+  //names from filename
+  names_from_filename = gtk_check_button_new_with_mnemonic(_("_Splitpoint name from filename (testing)"));
+  gtk_box_pack_start(GTK_BOX(vbox), names_from_filename, FALSE, FALSE, 0);
+  g_signal_connect(G_OBJECT(names_from_filename), "toggled",
+      G_CALLBACK(splitpoints_from_filename_event), NULL);
+
   create_dirs_from_output_files =
     gtk_check_button_new_with_mnemonic(_("_Create directories from filenames "));
   gtk_box_pack_start(GTK_BOX(vbox), create_dirs_from_output_files, FALSE, FALSE, 0);
@@ -616,10 +769,10 @@ GtkWidget *create_split_options_box()
   gtk_box_pack_start (GTK_BOX (horiz_fake), set_default_prefs_button,
                       FALSE, FALSE, 5);
 
-  return set_title_and_get_vbox(vbox, _("<b>Split options</b>"));
+  return wh_set_title_and_get_vbox(vbox, _("<b>Split options</b>"));
 }
 
-//creates the splitpoints preferences page
+//!creates the splitpoints preferences page
 GtkWidget *create_pref_splitpoints_page()
 {
   GtkWidget *general_hbox = gtk_hbox_new(FALSE,0);
@@ -643,37 +796,12 @@ GtkWidget *create_pref_splitpoints_page()
   return general_hbox;
 }
 
-//removes unavailable players from the combo
-void combo_remove_unavailable_players()
-{
-  //if we dont have GSTREAMER 
-#ifdef NO_GSTREAMER
-  gtk_combo_box_remove_text(GTK_COMBO_BOX(player_combo_box),
-                            PLAYER_GSTREAMER-1);
-  player_pref_list =
-    g_list_remove(player_pref_list, GINT_TO_POINTER(PLAYER_GSTREAMER));
-#endif
-
-  //if we dont have AUDACIOUS
-#ifdef NO_AUDACIOUS
-  gtk_combo_box_remove_text(GTK_COMBO_BOX(player_combo_box),
-                            PLAYER_AUDACIOUS-1);
-  player_pref_list =
-    g_list_remove(player_pref_list, GINT_TO_POINTER(PLAYER_AUDACIOUS));
-#endif
-}
-
-//event when changing the combo box player
+//!event when changing the combo box player
 void player_combo_box_event(GtkComboBox *widget, gpointer data)
 {
-  //disconnect from player
   disconnect_button_event(NULL, NULL);
 
-  gint selected_item;
-  selected_item = gtk_combo_box_get_active(widget);
-  gint sel_pl = GPOINTER_TO_INT(g_list_nth_data(player_pref_list, selected_item));
-
-  selected_player = sel_pl;
+  selected_player = ch_get_active_value(widget);
 
   if (selected_player == PLAYER_GSTREAMER)
   {
@@ -690,6 +818,7 @@ void player_combo_box_event(GtkComboBox *widget, gpointer data)
   save_preferences(NULL, NULL);
 }
 
+//!Create the box the player backend can be selected with
 GtkWidget *create_player_options_box()
 {
   GtkWidget *horiz_fake = gtk_hbox_new(FALSE,0);
@@ -697,31 +826,25 @@ GtkWidget *create_player_options_box()
   GtkWidget *label = gtk_label_new(_("Choose a player:"));
   gtk_box_pack_start(GTK_BOX(horiz_fake), label, FALSE, FALSE, 0);
 
-  player_combo_box = gtk_combo_box_new_text();
+  player_combo_box = GTK_WIDGET(ch_new_combo());
+
+#ifndef NO_AUDACIOUS
+  ch_append_to_combo(GTK_COMBO_BOX(player_combo_box), "Audacious", PLAYER_AUDACIOUS);
+#endif
+  ch_append_to_combo(GTK_COMBO_BOX(player_combo_box), "SnackAmp", PLAYER_SNACKAMP);
+#ifndef NO_GSTREAMER
+  ch_append_to_combo(GTK_COMBO_BOX(player_combo_box), "GStreamer", PLAYER_GSTREAMER);
+#endif
+
   g_signal_connect(G_OBJECT(player_combo_box), "changed",
       G_CALLBACK(player_combo_box_event), NULL);
-  
-  gtk_combo_box_insert_text(GTK_COMBO_BOX(player_combo_box),
-                            PLAYER_AUDACIOUS,"Audacious");
-  player_pref_list =
-    g_list_append(player_pref_list, GINT_TO_POINTER(PLAYER_AUDACIOUS));
-
-  gtk_combo_box_insert_text(GTK_COMBO_BOX(player_combo_box),
-                            PLAYER_SNACKAMP,"SnackAmp");
-  player_pref_list =
-    g_list_append(player_pref_list, GINT_TO_POINTER(PLAYER_SNACKAMP));
-
-  gtk_combo_box_insert_text(GTK_COMBO_BOX(player_combo_box),
-                            PLAYER_GSTREAMER,"GStreamer");
-  player_pref_list =
-    g_list_append(player_pref_list, GINT_TO_POINTER(PLAYER_GSTREAMER));
 
   gtk_box_pack_start(GTK_BOX(horiz_fake), player_combo_box, FALSE, FALSE, 12);
  
-  return set_title_and_get_vbox(horiz_fake, _("<b>Player options</b>"));
+  return wh_set_title_and_get_vbox(horiz_fake, _("<b>Player options</b>"));
 }
 
-//creates the player preferences page
+//!creates the player preferences page
 GtkWidget *create_pref_player_page()
 {
   GtkWidget *player_hbox = gtk_hbox_new(FALSE, 0);;
@@ -744,7 +867,7 @@ GtkWidget *create_pref_player_page()
   return player_hbox;
 }
 
-//update the save buttons when output entry event
+//!update the save buttons on an output entry event
 gboolean output_entry_event(GtkWidget *widget, GdkEventKey *event,
     gpointer user_data)
 {
@@ -760,6 +883,7 @@ gboolean output_entry_event(GtkWidget *widget, GdkEventKey *event,
   return FALSE;
 }
 
+//!Create the box the output file name is displayed in
 GtkWidget *create_output_filename_box()
 {
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
@@ -777,7 +901,7 @@ GtkWidget *create_output_filename_box()
   gtk_box_pack_start(GTK_BOX(vbox), horiz_fake, FALSE, FALSE, 5);
 
   output_entry = gtk_entry_new();
-  gtk_entry_set_editable(GTK_ENTRY(output_entry), TRUE);
+  gtk_editable_set_editable(GTK_EDITABLE(output_entry), TRUE);
   g_signal_connect(G_OBJECT(output_entry), "key_release_event",
       G_CALLBACK(output_entry_event), NULL);
   gtk_entry_set_max_length(GTK_ENTRY(output_entry),244);
@@ -792,16 +916,17 @@ GtkWidget *create_output_filename_box()
         " always exist)\n"
         "    @b - album title\n"
         "    @t - song title\n"
+        "    @g - genre\n"
         "    @n - track number"));
   gtk_box_pack_start(GTK_BOX(horiz_fake), output_label, FALSE, FALSE, 0);
 
   g_signal_connect(GTK_TOGGLE_BUTTON(radio_output),
       "toggled", G_CALLBACK(output_radio_box_event), output_label);
 
-  return set_title_and_get_vbox(vbox, _("<b>Output filename format</b>"));
+  return wh_set_title_and_get_vbox(vbox, _("<b>Output filename format</b>"));
 }
 
-//creates the output preferences page
+//!creates the output preferences page
 GtkWidget *create_pref_output_page()
 {
   GtkWidget *output_hbox = gtk_hbox_new(FALSE, 0);;
@@ -821,33 +946,245 @@ GtkWidget *create_pref_output_page()
   return output_hbox;
 }
 
+void change_tags_options(GtkToggleButton *button, gpointer data)
+{
+  if (extract_tags_box != NULL)
+  {
+    if (rh_get_active_value(tags_radio) == TAGS_FROM_FILENAME)
+    {
+      gtk_widget_set_sensitive(extract_tags_box, SPLT_TRUE);
+    }
+    else
+    {
+      gtk_widget_set_sensitive(extract_tags_box, SPLT_FALSE);
+    }
+  }
+
+  save_preferences(NULL, NULL);
+}
+
+//!Create the box for the Tags options
 GtkWidget *create_tags_options_box()
 {
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
 
-  GtkWidget *horiz_fake = gtk_hbox_new(FALSE,0);
-  gtk_box_pack_start(GTK_BOX(vbox), horiz_fake, FALSE, FALSE, 0);
+  tags_radio = rh_append_radio_to_vbox(tags_radio, _("Original file tags"),
+      ORIGINAL_FILE_TAGS, change_tags_options, vbox);
 
-  tags_radio = gtk_radio_button_new_with_label(NULL, _("Original file tags"));
-  gtk_box_pack_start(GTK_BOX(vbox), tags_radio, FALSE, FALSE, 0);
-  g_signal_connect(GTK_TOGGLE_BUTTON(tags_radio), "toggled", 
-      G_CALLBACK(save_preferences), NULL);
+  tags_radio = rh_append_radio_to_vbox(tags_radio, _("Default tags (cddb or cue tags)"),
+      DEFAULT_TAGS, change_tags_options, vbox);
 
-  tags_radio = gtk_radio_button_new_with_label_from_widget
-    (GTK_RADIO_BUTTON(tags_radio), _("Default tags (cddb or cue tags)"));
-  g_signal_connect(GTK_TOGGLE_BUTTON(tags_radio), "toggled", 
-      G_CALLBACK(save_preferences), NULL);
-  gtk_box_pack_start(GTK_BOX(vbox), tags_radio, FALSE, FALSE, 0);
+  tags_radio = rh_append_radio_to_vbox(tags_radio, _("No tags"),
+      NO_TAGS, change_tags_options, vbox);
 
-  tags_radio = gtk_radio_button_new_with_label_from_widget(
-      GTK_RADIO_BUTTON(tags_radio),_("No tags"));
-  g_signal_connect(GTK_TOGGLE_BUTTON(tags_radio), "toggled", 
-      G_CALLBACK(save_preferences), NULL);
-  gtk_box_pack_start(GTK_BOX(vbox), tags_radio, FALSE, FALSE, 0);
+  tags_radio = rh_append_radio_to_vbox(tags_radio, _("Extract tags from filename"),
+      TAGS_FROM_FILENAME, change_tags_options, vbox);
 
-  return set_title_and_get_vbox(vbox, _("<b>Split files tags</b>"));
+  extract_tags_box = create_extract_tags_from_filename_options_box();
+  gtk_widget_set_sensitive(extract_tags_box, SPLT_FALSE);
+  gtk_box_pack_start(GTK_BOX(vbox), extract_tags_box, FALSE, FALSE, 2);
+
+  return wh_set_title_and_get_vbox(vbox, _("<b>Split files tags</b>"));
 }
 
+static GtkComboBox *create_genre_combo()
+{
+  GtkComboBox *combo = ch_new_combo();
+
+  int i = 0;
+  for (i = 0;i < SPLT_ID3V1_NUMBER_OF_GENRES;i++)
+  {
+    ch_append_to_combo(combo, splt_id3v1_genres[i], 0);
+  }
+
+  g_signal_connect(G_OBJECT(combo), "changed", G_CALLBACK(save_preferences), NULL);
+
+  return combo;
+}
+
+static GtkComboBox *create_text_preferences_combo()
+{
+  GtkComboBox *combo = ch_new_combo();
+
+  ch_append_to_combo(combo, _("No change"), SPLT_NO_CONVERSION);
+  ch_append_to_combo(combo, _("lowercase"), SPLT_TO_LOWERCASE);
+  ch_append_to_combo(combo, _("UPPERCASE"), SPLT_TO_UPPERCASE);
+  ch_append_to_combo(combo, _("First uppercase"), SPLT_TO_FIRST_UPPERCASE);
+  ch_append_to_combo(combo, _("Word Uppercase"), SPLT_TO_WORD_FIRST_UPPERCASE);
+
+  g_signal_connect(G_OBJECT(combo), "changed", G_CALLBACK(save_preferences), NULL);
+
+  return combo;
+}
+
+void test_regex_event(GtkWidget *widget, gpointer data)
+{
+  put_tags_from_filename_regex_options();
+  const gchar *test_regex_filename = gtk_entry_get_text(GTK_ENTRY(test_regex_fname_entry));
+  mp3splt_set_filename_to_split(the_state, test_regex_filename);
+
+  gint error = SPLT_OK;
+  splt_tags *tags = mp3splt_parse_filename_regex(the_state, &error);
+  print_status_bar_confirmation(error);
+
+  if (error >= 0)
+  {
+    GString *regex_result = g_string_new(NULL);
+
+    g_string_append(regex_result, _("<artist>: "));
+    if (tags->artist)
+    {
+      g_string_append(regex_result, tags->artist);
+    }
+    g_string_append(regex_result, "\n");
+
+    g_string_append(regex_result, _("<album>: "));
+    if (tags->album)
+    {
+      g_string_append(regex_result, tags->album);
+    }
+    g_string_append(regex_result, "\n");
+
+
+    g_string_append(regex_result, _("<title>: "));
+    if (tags->title)
+    {
+      g_string_append(regex_result, tags->title);
+    }
+    g_string_append(regex_result, "\n");
+
+    g_string_append(regex_result, _("<genre>: "));
+    if (tags->genre)
+    {
+      g_string_append(regex_result, tags->genre);
+    }
+    g_string_append(regex_result, "\n");
+
+    g_string_append(regex_result, _("<comment>: "));
+    if (tags->comment)
+    {
+      g_string_append(regex_result, tags->comment);
+    }
+    g_string_append(regex_result, "\n");
+
+    g_string_append(regex_result, _("<year>: "));
+    if (tags->year)
+    {
+      g_string_append(regex_result, tags->year);
+    }
+    g_string_append(regex_result, "\n");
+
+    g_string_append(regex_result, _("<track>: "));
+    if (tags->track >= 0)
+    {
+      g_string_append_printf(regex_result, "%d", tags->track);
+    }
+
+    gchar *regex_result_text = g_string_free(regex_result, FALSE);
+    if (regex_result_text)
+    {
+      gtk_label_set_text(GTK_LABEL(sample_result_label), regex_result_text);
+      g_free(regex_result_text);
+    }
+  }
+  else
+  {
+    gtk_label_set_text(GTK_LABEL(sample_result_label), "");
+  }
+
+  mp3splt_free_one_tag(tags);
+}
+
+static GtkWidget *create_extract_tags_from_filename_options_box()
+{
+  GtkWidget *table = wh_new_table();
+
+  regex_entry = wh_new_entry(save_preferences);
+  wh_add_in_table_with_label_expand(table, _("Regular expression:"), regex_entry);
+
+  GtkWidget *regex_label = gtk_label_new(_(
+        "Above enter PERL-like regular expression using named subgroups.\nFollowing names are recognized:\n"
+        "    (?<artist>)   - artist name\n"
+        "    (?<album>)    - album title\n"
+        "    (?<title>)    - track title\n"
+        "    (?<tracknum>) - current track number\n"
+        //"    (?<tracks>)   - total number of tracks\n"
+        "    (?<year>)     - year of emission\n"
+        "    (?<genre>)    - genre\n"
+        "    (?<comment>)  - comment"));
+  gtk_misc_set_alignment(GTK_MISC(regex_label), 0.0, 0.5);
+  wh_add_in_table(table, wh_put_in_new_hbox_with_margin_level(regex_label, 2));
+
+  text_options_list =
+    g_list_append(text_options_list, GINT_TO_POINTER(SPLT_NO_CONVERSION));
+  text_options_list = 
+    g_list_append(text_options_list, GINT_TO_POINTER(SPLT_TO_LOWERCASE));
+  text_options_list = 
+    g_list_append(text_options_list, GINT_TO_POINTER(SPLT_TO_UPPERCASE));
+  text_options_list =
+    g_list_append(text_options_list, GINT_TO_POINTER(SPLT_TO_FIRST_UPPERCASE));
+  text_options_list =
+    g_list_append(text_options_list, GINT_TO_POINTER(SPLT_TO_WORD_FIRST_UPPERCASE));
+
+  replace_underscore_by_space_check_box =
+    gtk_check_button_new_with_mnemonic(_("_Replace underscores by spaces"));
+  g_signal_connect(G_OBJECT(replace_underscore_by_space_check_box), "toggled",
+      G_CALLBACK(save_preferences), NULL);
+ 
+  wh_add_in_table(table, replace_underscore_by_space_check_box);
+
+  artist_text_properties_combo = create_text_preferences_combo();
+  wh_add_in_table_with_label(table, 
+      _("Artist text properties:"), GTK_WIDGET(artist_text_properties_combo));
+
+  album_text_properties_combo = create_text_preferences_combo();
+  wh_add_in_table_with_label(table,
+      _("Album text properties:"), GTK_WIDGET(album_text_properties_combo));
+
+  title_text_properties_combo = create_text_preferences_combo();
+  wh_add_in_table_with_label(table,
+      _("Title text properties:"), GTK_WIDGET(title_text_properties_combo));
+
+  comment_text_properties_combo = create_text_preferences_combo();
+  wh_add_in_table_with_label(table,
+      _("Comment text properties:"), GTK_WIDGET(comment_text_properties_combo));
+
+  genre_combo = create_genre_combo();
+  wh_add_in_table_with_label(table, _("Genre tag:"), GTK_WIDGET(genre_combo));
+
+  comment_tag_entry = wh_new_entry(save_preferences);
+  wh_add_in_table_with_label_expand(table, _("Comment tag:"), comment_tag_entry);
+
+  GtkWidget *test_regex_expander = gtk_expander_new(_("Regular expression test"));
+  gtk_container_add(GTK_CONTAINER(test_regex_expander), create_test_regex_table());
+  wh_add_in_table(table, test_regex_expander);
+
+  return wh_put_in_new_hbox_with_margin_level(GTK_WIDGET(table), 3);
+}
+
+static GtkWidget *create_test_regex_table()
+{
+  GtkWidget *table = wh_new_table();
+
+  GtkWidget *sample_test_hbox = gtk_hbox_new(FALSE, 0);
+  test_regex_fname_entry = wh_new_entry(save_preferences);
+  gtk_box_pack_start(GTK_BOX(sample_test_hbox), test_regex_fname_entry, TRUE, TRUE, 0);
+
+  GtkWidget *test_regex_button = wh_new_button(_("_Test"));
+  gtk_box_pack_start(GTK_BOX(sample_test_hbox), test_regex_button, FALSE, FALSE, 5);
+  g_signal_connect(G_OBJECT(test_regex_button), "clicked",
+      G_CALLBACK(test_regex_event), NULL);
+
+  wh_add_in_table_with_label_expand(table, _("Sample filename:"), sample_test_hbox);
+
+  sample_result_label = gtk_label_new("");
+  gtk_misc_set_alignment(GTK_MISC(sample_result_label), 0.0, 0.5);
+  wh_add_in_table_with_label_expand(table, _("Sample result:"), sample_result_label);
+
+  return wh_put_in_new_hbox_with_margin_level(GTK_WIDGET(table), 3);
+}
+
+//!Create the box we can select with if to create ID1 and/or ID2 Tags
 GtkWidget *create_tags_version_box()
 {
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
@@ -877,9 +1214,10 @@ GtkWidget *create_tags_version_box()
       G_CALLBACK(save_preferences), NULL);
   gtk_box_pack_start(GTK_BOX(vbox), tags_version_radio, FALSE, FALSE, 0);
 
-  return set_title_and_get_vbox(vbox, _("<b>Tags version (mp3 only)</b>"));
+  return wh_set_title_and_get_vbox(vbox, _("<b>Tags version (mp3 only)</b>"));
 }
 
+//! Create the tags settings tab
 GtkWidget *create_pref_tags_page()
 {
   GtkWidget *outside_vbox = gtk_vbox_new(FALSE, 0);;
@@ -893,16 +1231,16 @@ GtkWidget *create_pref_tags_page()
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);;
   gtk_box_pack_start(GTK_BOX(inside_hbox), vbox, TRUE, TRUE, 10);
 
-  GtkWidget *tags_opts_box = create_tags_options_box();
-  gtk_box_pack_start(GTK_BOX(vbox), tags_opts_box, FALSE, FALSE, 10);
-
   GtkWidget *tags_version_box = create_tags_version_box();
-  gtk_box_pack_start(GTK_BOX(vbox), tags_version_box, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), tags_version_box, FALSE, FALSE, 10);
+
+  GtkWidget *tags_opts_box = create_tags_options_box();
+  gtk_box_pack_start(GTK_BOX(vbox), tags_opts_box, FALSE, FALSE, 0);
   
   return outside_vbox;
 }
 
-//creates the preferences 
+//!creates the preferences tab
 GtkWidget *create_choose_preferences()
 {
   //our preferences vbox
@@ -947,7 +1285,6 @@ GtkWidget *create_choose_preferences()
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook), language_prefs,
                            (GtkWidget *)notebook_label);
 #endif
-
+  
   return pref_vbox;
 }
-
