@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright (c) 2005-2010 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2011 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
  *
@@ -35,9 +35,18 @@
  *
  *********************************************************/
 
+#ifndef _PREFERENCES_TAB_H
+#define _PREFERENCES_TAB_H
+
+#define NUMBER_OF_TAGS_MODES 4
+
+#define NO_TAGS 0
+#define DEFAULT_TAGS 1
+#define ORIGINAL_FILE_TAGS 2
+#define TAGS_FROM_FILENAME 3
+
 GtkWidget *create_scrolled_window();
 gboolean get_checked_output_radio_box();
-gint get_checked_tags_radio_box();
 gint get_checked_tags_version_radio_box();
 void radio_box_changed_event(GtkToggleButton *radio_b, gpointer data);
 GtkWidget *create_pref_general_page();
@@ -57,3 +66,6 @@ void player_combo_box_event(GtkComboBox *widget, gpointer data);
 GtkWidget *create_choose_player_combo();
 GtkWidget *create_pref_player_page();
 GtkWidget *create_choose_preferences();
+void outputdirectory_set(gchar *dirname);
+gchar *outputdirectory_get();
+#endif
