@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright (c) 2005-2010 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2011 Alexandru Munteanu - io_fx@yahoo.fr
  *
  *
  * http://mp3splt.sourceforge.net/
@@ -34,13 +34,15 @@
 #define FILE_MODE_SINGLE 1
 #define FILE_MODE_MULTIPLE 0
 
+#define SELECTED_SPLIT_TRIM_SILENCE 6
+#define SELECTED_SPLIT_SILENCE 5
 #define SELECTED_SPLIT_EQUAL_TIME_TRACKS 4
 #define SELECTED_SPLIT_NORMAL 3
 #define SELECTED_SPLIT_TIME 2
 #define SELECTED_SPLIT_WRAP 1
 #define SELECTED_SPLIT_ERROR 0
 
-#define NUMBER_OF_SPLIT_MODES 5
+#define NUMBER_OF_SPLIT_MODES 6
 
 void select_split_mode(int split_mode);
 
