@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -29,13 +29,13 @@
  *
  *********************************************************/
 
-/**********************************************************
- * Filename: tree_tab.c
+/*!********************************************************
+ * \file 
+ * The splitpoints tab
  *
  * this file is used for the Splitpoints tab
- * (for the splitpoints table)
- *
- *********************************************************/
+ * (which in turn contains the splitpoints table)
+ **********************************************************/
 
 #include <string.h>
 #include <stdlib.h>
@@ -61,27 +61,11 @@
 #include "split_files.h"
 #include "preferences_tab.h"
 #include "preferences_manager.h"
+#include "tree_tab.h"
+/*! The array all splitpoints are kept in.
 
-//tree column enumeration
-enum {
-  /* if we enable this splitpoint for split */
-  COL_CHECK,
-  /* the filename of the split */
-  COL_DESCRIPTION,
-  /* splitpoints, minutes, seconds,hundr */
-  COL_MINUTES,
-  COL_SECONDS,
-  COL_HUNDR_SECS,
-  /* length of the split song */
-  COL_NUMBER,
-  /* preview button */
-  COL_PREVIEW,
-  /* split preview button */
-  COL_SPLIT_PREVIEW,
-  NUM_COLUMNS = 8
-};
-
-//splitpoints
+The splitpoints themself will be in the 
+ */
 GArray *splitpoints = NULL;
 //minutes and seconds reflected by the spinners
 gint spin_mins = 0;
@@ -90,9 +74,10 @@ gint spin_hundr_secs = 0;
 //if we have a skippoint or a splitpoint
 gint splitpoint_checked = TRUE;
 //current description
+//TODO: not translated
 gchar current_description[255] = "description here";
 
-//splitpoints elements number
+//! The total number of splitpoints
 gint splitnumber = 0;
 
 //buttons for adding and removing rows
@@ -102,61 +87,87 @@ GtkWidget *remove_row_button = NULL;
 
 //special buttons like 'set splitpoints from silence detection
 GtkWidget *scan_silence_button = NULL;
+GtkWidget *scan_trim_silence_button = NULL;
 
 //handle box for detaching window
 GtkWidget *handle_box;
 
-//our tree view, used global for 
-//the update_*_from_spinner
+/*! The tree view (which is the table all split points are stored inside)
+
+Used globally for the update_*_from_spinner; the information about the
+order of items is kept in the enum tree_columns.
+*/
 GtkTreeView *tree_view;
 
-//minutes and seconds spinner
+/*!\defgroup{} splitpointview Variables for the splitpoint view
+@{
+*/
+//!The minutes spinner
 GtkWidget *spinner_minutes;
+//!The seconds spinner
 GtkWidget *spinner_seconds;
+//!The hundreths of seconds spinner
 GtkWidget *spinner_hundr_secs;
 
-//if we have a preview, preview = TRUE
+//!if we have a preview, preview = TRUE
 gboolean quick_preview = FALSE;
-//the end of the preview
-//preview_end_position = -1 means don't stop until the
-//end of the song
+/*! the end of the preview
+
+preview_end_position = -1 means don't stop until the
+end of the song
+*/
 gint quick_preview_end_splitpoint = -1;
 
-//for the preview
+//! The number of the split point for the preview
 gint this_row = 0;
-//the position transmitted to the player
+//! the position transmitted to the player
 gint preview_start_position;
+//! Which splitpoint we started the preview at
 gint preview_start_splitpoint = -1;
 
-//if we add a new splitpoint at the left and we are currently
-//previewing, we should increment quick_preview start and end
+/*! A bool that helps us catch the case that we add splitpoints during preview
+
+if we add a new splitpoint at the left and we are currently
+previewing, we should increment quick_preview start and end
+*/
 gboolean new_left_splitpoint_added = FALSE;
 
-//the splitpoint selected, used when we move the splitpoint
-//we have selected
+/*!  The selected splitpoint
+
+used when we move the splitpoint we have selected
+*/
 gint first_splitpoint_selected = -1;
+//@}
 
-//silence detection parameters widgets
-//number of tracks parameter
-GtkWidget *spinner_silence_number_tracks;
-//number of tracks parameter
-GtkWidget *spinner_silence_minimum;
-//offset parameter
-GtkWidget *spinner_silence_offset;
-//threshold parameter
+/*! \defgroup silencedetectiongroup silence detection parameters widgets
+@{
+*/
+//!number of tracks parameter
+GtkWidget *spinner_silence_number_tracks = NULL;
+GtkWidget *spinner_silence_minimum = NULL;
+GtkWidget *spinner_silence_minimum_track = NULL;
+//!offset parameter
+GtkWidget *spinner_silence_offset = NULL;
+//!threshold parameter
 GtkWidget *spinner_silence_threshold;
-//remove silence check button (silence mode parameter
-GtkWidget *silence_remove_silence;
+//!remove silence check button (silence mode parameter
+GtkWidget *silence_remove_silence = NULL;
+// @}
 
-//silence split parameters
+/*!\defgroup silencesplitparameters silence split parameters
+  @{
+*/
 gfloat silence_threshold_value = SPLT_DEFAULT_PARAM_THRESHOLD; 
 gfloat silence_offset_value = SPLT_DEFAULT_PARAM_OFFSET;
 gint silence_number_of_tracks = SPLT_DEFAULT_PARAM_TRACKS;
 gfloat silence_minimum_length = SPLT_DEFAULT_PARAM_MINIMUM_LENGTH;
+gfloat silence_minimum_track_length = SPLT_DEFAULT_PARAM_MINIMUM_TRACK_LENGTH;
 gboolean silence_remove_silence_between_tracks = FALSE;
+//@}
 
-//options for splitting
-extern GtkWidget *entry;
+/*!\defgroup SplitOptionGroup options for splitting
+\{
+*/
 extern gint timer_active;
 extern gint player_seconds, player_minutes,
   player_hundr_secs;
@@ -176,8 +187,19 @@ extern GtkWidget *window;
 extern GtkWidget *output_entry;
 extern gint debug_is_active;
 
-//updates add button, wether the spinners splitpoint is already
-//in the table or not
+extern GtkWidget *names_from_filename;
+//@}
+
+extern void put_split_filename(const char *filename,int progress_data);
+
+
+void copy_filename_to_current_description(const gchar *fname);
+
+/*! updates add button
+
+Makes the add button show whether the spinners splitpoint is already
+in the table or not
+*/
 void update_add_button()
 {
   if (check_if_splitpoint_does_not_exists(tree_view,
@@ -193,7 +215,7 @@ void update_add_button()
     }
 }
 
-//updates the minutes from the spinner
+//!updates the minutes from the spinner
 void update_minutes_from_spinner( GtkWidget *widget,
                                   gpointer   data )
 {
@@ -202,7 +224,7 @@ void update_minutes_from_spinner( GtkWidget *widget,
   update_add_button();
 }
 
-//updates the seconds from the spinner
+//!updates the seconds from the spinner
 void update_seconds_from_spinner( GtkWidget *widget,
                                   gpointer   data )
 {
@@ -211,7 +233,7 @@ void update_seconds_from_spinner( GtkWidget *widget,
   update_add_button();
 }
 
-//updates the hundredth of seconds for the spinner
+//!updates the hundredth of seconds for the spinner
 void update_hundr_secs_from_spinner( GtkWidget *widget,
                                      gpointer   data )
 {
@@ -220,7 +242,7 @@ void update_hundr_secs_from_spinner( GtkWidget *widget,
   update_add_button();
 }
 
-//creates the model for the tree, gtkliststore
+//!creates the model for the tree, gtkliststore
 GtkTreeModel *create_model()
 {
   GtkListStore *model;
@@ -236,7 +258,7 @@ GtkTreeModel *create_model()
   return GTK_TREE_MODEL (model);
 }
 
-//order the number column
+//!order the number column
 void order_length_column(GtkTreeView *tree_view)
 {
   //number to be put in the number column
@@ -331,8 +353,7 @@ void order_length_column(GtkTreeView *tree_view)
     }
 }
 
-//checks if splitpoints exists in the table
-//and different from current_split
+//! checks if splitpoints exists in the table and is different from current_split
 gboolean check_if_splitpoint_does_not_exists(GtkTreeView *tree_view,
     gint minutes, 
     gint seconds,
@@ -400,8 +421,13 @@ gboolean check_if_splitpoint_does_not_exists(GtkTreeView *tree_view,
   return TRUE;
 }
 
-//checks if description exists
-//we dont check the count = number
+/*! checks if the name of the current track is already in use
+
+\param descr The name of the current track
+\param number The number of the track we don't want to compare our
+track name with
+\result TRUE if the new track name for track (number) is unique
+*/
 gboolean check_if_description_exists(gchar *descr,
                                      gint number)
 {
@@ -417,6 +443,8 @@ gboolean check_if_description_exists(gchar *descr,
   //get iter number
   if(gtk_tree_model_get_iter_first(model, &iter))
     {
+      // Todo: Do the next 2 lines make any sense?
+      // I mean: They will be repeated later.
       gtk_tree_model_get(GTK_TREE_MODEL(model), &iter,
                          COL_DESCRIPTION,&description,
                          -1);
@@ -455,7 +483,7 @@ gboolean check_if_description_exists(gchar *descr,
   return TRUE;
 }
 
-//returns the first splitpoint selected
+//!Gets the number of the first splitpoint with selected "Keep" checkbox 
 gint get_first_splitpoint_selected()
 {
   gint splitpoint_selected = -1;
@@ -491,45 +519,60 @@ gint get_first_splitpoint_selected()
   return splitpoint_selected;
 }
 
-//row selection event
+//!row selection event
 void row_selection_event()
 {
-  if(!GTK_WIDGET_SENSITIVE(remove_row_button))
+  if(!gtk_widget_get_sensitive(remove_row_button))
     gtk_widget_set_sensitive(GTK_WIDGET(remove_row_button), TRUE); 
 }
 
-//we dont check count = number
+/*! Set the name of the splitpoint (number) to (descr)
+
+\param descr the new name of the split point
+\param number The number of the split point
+
+If any split point with a different number already uses the name we
+want we chose for this split point this function adds a number as a
+postfix (or updates the already-existing postfix) to force the new
+splitpoint's name. do be unique.
+*/
 void update_current_description(gchar *descr, gint number)
 {
   gint ll = 0;
-  
+
   g_snprintf(current_description,255,"%s",descr);
-  
+
   while (ll < splitnumber)
+  {
+    //if we already have the description
+    if(!check_if_description_exists(current_description, number))
     {
-      //if we already have the description
-      if(!check_if_description_exists(current_description,
-                                      number))
-        {
-          //we cut the part _* from the string and put
-          //it back
-          gchar *tmp;
-          tmp = strchr(current_description,'_');
-          if (tmp != NULL)
-            {
-              *tmp = '\0';
-            }
-          gchar *temp = g_strdup(current_description);
-          g_snprintf(current_description,255, "%s_%d_",temp,ll);
-          //freeing memory
-          g_free(temp);
-        }
-      ll++;
+      //we cut the part _* from the string and put
+      //it back
+      gchar *tmp = NULL;
+      gchar *t = current_description;
+      while ((t = strstr(t, _("_part"))) != NULL)
+      {
+        tmp = t++;
+      }
+
+      if (tmp != NULL)
+      {
+        *tmp = '\0';
+      }
+
+      gchar *temp = g_strdup(current_description);
+      g_snprintf(current_description, 255, _("%s_part%d"), temp, ll + 2);
+      g_free(temp);
     }
+    ll++;
+  }
 }
 
-//returns secs, mins, hundr of secs from a time
-//not used for now
+/*!returns secs, mins, hundr of secs from a time
+
+not used for now
+*/
 void get_hundr_secs_mins_time(gint time_pos, gint *time_hundr,
                               gint *time_secs,gint *time_mins)
 {
@@ -540,7 +583,7 @@ void get_hundr_secs_mins_time(gint time_pos, gint *time_hundr,
   *time_mins = time_pos;
 }
 
-//selects a splitpoint
+//!selects a splitpoint
 void select_splitpoint(gint index)
 {
   GtkTreeModel *model;
@@ -563,8 +606,10 @@ void select_splitpoint(gint index)
   remove_status_message();
 }
 
-//removes a splitpoint
-//stop preview means we stop preview if necessary
+/*! removes a splitpoint
+\param index Number of the split point
+\param stop_preview means we stop preview if necessary
+*/
 void remove_splitpoint(gint index,gint stop_preview)
 {
   //remove values from the splitpoint array
@@ -599,7 +644,7 @@ void remove_splitpoint(gint index,gint stop_preview)
   //if we don't have the first selected, we hide remove button
   if (get_first_splitpoint_selected() == -1)
     {
-      if(GTK_WIDGET_SENSITIVE(remove_row_button))
+      if(gtk_widget_get_sensitive(remove_row_button))
         gtk_widget_set_sensitive(GTK_WIDGET(remove_row_button), 
                                  FALSE);  
     }
@@ -608,7 +653,7 @@ void remove_splitpoint(gint index,gint stop_preview)
   if (splitnumber == 0)
     {
       //disable remove all button
-      if(GTK_WIDGET_SENSITIVE(remove_all_button))
+      if(gtk_widget_get_sensitive(remove_all_button))
         gtk_widget_set_sensitive(GTK_WIDGET(remove_all_button), FALSE);
     }
   
@@ -620,7 +665,15 @@ void remove_splitpoint(gint index,gint stop_preview)
   refresh_drawing_area();
 }
 
-//updates a splipoint
+/*!Set all values of a split point
+
+\param new_point All values for this split point
+\param index The number of this split point
+
+Will display an error in the message bar if a splitpoint with a
+different index number with exactly the same time value exists and
+otherwise update the split point.
+*/
 void update_splitpoint(gint index, Split_point new_point)
 {
   int splitpoint_does_not_exists = check_if_splitpoint_does_not_exists(tree_view,
@@ -658,8 +711,10 @@ void update_splitpoint(gint index, Split_point new_point)
   }
 }
 
-//updates a splitpoint
-//index is the position in the GArray with splitpoints
+/*!Set a splitpoint's time value
+\param index The split point's number
+\param time the new time value
+*/
 void update_splitpoint_from_time(gint index, gdouble time)
 {
   //if we have another splitpoint on the same place
@@ -674,8 +729,11 @@ void update_splitpoint_from_time(gint index, gdouble time)
   update_splitpoint(index, new_point);
 }
 
-//updates a splitpoint
-//index is the position in the GArray with splitpoints
+/*!Toggles a splitpoint's "Keep" flag
+
+\param index is the position in the GArray with splitpoints aka the
+split point's number
+*/
 void update_splitpoint_check(gint index)
 {
   Split_point old_point = g_array_index(splitpoints, Split_point, index);
@@ -683,7 +741,7 @@ void update_splitpoint_check(gint index)
   update_splitpoint(index, old_point);
 }
 
-//event for editing a cell
+//!event for editing a cell
 void cell_edited_event (GtkCellRendererText *cell,
                         gchar               *path_string,
                         gchar               *new_text,
@@ -723,8 +781,16 @@ void cell_edited_event (GtkCellRendererText *cell,
                           &iter,
                           col, current_description,
                           -1);
-      
-      g_snprintf(current_description, 255, "%s", _("description here"));      
+     
+      if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(names_from_filename)))
+      {
+        const gchar *fname = inputfilename_get();
+        copy_filename_to_current_description(fname);
+      }
+      else
+      {
+        g_snprintf(current_description, 255, "%s", _("description here"));
+      }
       break;
       //seconds column
     case COL_SECONDS:
@@ -800,9 +866,43 @@ void add_splitpoint_from_player(GtkWidget *widget,
     }
 }
 
-//adds a splitpoint
-//old_index is used when we update a splitpoint
-//to see where we had the play_preview point
+void clear_current_description(void)
+{
+  update_current_description(_("description here"), -1);
+}
+
+void copy_filename_to_current_description(const gchar *fname)
+{
+  if (strcmp(fname, "") == 0)
+  {
+    clear_current_description();
+  }
+
+  gchar *tmp;
+  gchar *basename = g_path_get_basename(fname);
+
+  // create copy of this string
+  gchar *temp = g_strdup(basename);
+
+  // last occurence of '.' distinguishes the extensions
+  tmp = strrchr(temp,'.');
+  if (tmp != NULL)
+  {
+    // there is a dot, kill the rest of the word (which is
+    // extension)
+    *tmp = '\0';
+  }
+
+  g_snprintf(current_description, 255, "%s", temp);
+  g_free(temp);
+}
+
+/*! adds a splitpoint
+
+\param my_split_point The data for our new split point
+\param old_index used when we update a splitpoint to see where we had
+the play_preview point 
+*/
 void add_splitpoint(Split_point my_split_point,
                     gint old_index)
 {
@@ -1001,7 +1101,7 @@ void add_splitpoint(Split_point my_split_point,
                           -1);
                 
       //enable remove all rows button if needed
-      if(!GTK_WIDGET_SENSITIVE(remove_all_button))
+      if(!gtk_widget_get_sensitive(remove_all_button))
         {
           gtk_widget_set_sensitive(GTK_WIDGET(remove_all_button), TRUE);
         }
@@ -1015,7 +1115,15 @@ void add_splitpoint(Split_point my_split_point,
       put_status_message(_(" error: you already have the splitpoint in table"));
     }
   
-  g_snprintf(current_description, 255, "%s", _("description here"));
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(names_from_filename)))
+  {
+    const gchar *fname = inputfilename_get();
+    copy_filename_to_current_description(fname);
+  }
+  else
+  {
+    g_snprintf(current_description, 255, "%s", _("description here"));
+  }
   
   //
   update_add_button();
@@ -1023,7 +1131,7 @@ void add_splitpoint(Split_point my_split_point,
   check_update_down_progress_bar();
 }
 
-//adds a row to the table
+//!adds a row to the table
 void add_row(gboolean checked)
 {
   Split_point my_split_point;
@@ -1041,19 +1149,22 @@ void add_row_clicked(GtkWidget *button, gpointer data)
   add_row(TRUE);
 }
 
-//set splitpints from silence detection
+//!set splitpints from silence detection
 gpointer detect_silence_and_set_splitpoints(gpointer data)
 {
+  gint should_trim = GPOINTER_TO_INT(data);
+
   gint err = SPLT_OK;
 
-  gdk_threads_enter();
+  enter_threads();
 
   gtk_widget_set_sensitive(GTK_WIDGET(scan_silence_button), FALSE);
+  gtk_widget_set_sensitive(GTK_WIDGET(scan_trim_silence_button), FALSE);
   gtk_widget_set_sensitive(cancel_button, TRUE);
-  filename_to_split = (gchar *) gtk_entry_get_text(GTK_ENTRY(entry));
+  filename_to_split = inputfilename_get();
   gchar *format = strdup(gtk_entry_get_text(GTK_ENTRY(output_entry)));
 
-  gdk_threads_leave();
+  exit_threads();
 
   mp3splt_set_filename_to_split(the_state, filename_to_split);
   mp3splt_erase_all_splitpoints(the_state, &err);
@@ -1069,22 +1180,29 @@ gpointer detect_silence_and_set_splitpoints(gpointer data)
   }
 
   mp3splt_set_int_option(the_state, SPLT_OPT_PRETEND_TO_SPLIT, SPLT_TRUE);
+  mp3splt_set_split_filename_function(the_state, NULL);
   int old_split_mode = mp3splt_get_int_option(the_state, SPLT_OPT_SPLIT_MODE, &err);
-  mp3splt_set_int_option(the_state, SPLT_OPT_SPLIT_MODE, SPLT_OPTION_SILENCE_MODE);
   int old_tags_option = mp3splt_get_int_option(the_state, SPLT_OPT_TAGS, &err);
   mp3splt_set_int_option(the_state, SPLT_OPT_TAGS, SPLT_TAGS_ORIGINAL_FILE);
   if (err >= 0)
   {
     we_are_splitting = TRUE;
-    //real work
-    err = mp3splt_split(the_state);
+    if (should_trim)
+    {
+      mp3splt_set_trim_silence_points(the_state, &err);
+    }
+    else
+    {
+      mp3splt_set_silence_points(the_state, &err);
+    }
     we_are_splitting = FALSE;
   }
   mp3splt_set_int_option(the_state, SPLT_OPT_TAGS, old_tags_option);
   mp3splt_set_int_option(the_state, SPLT_OPT_SPLIT_MODE, old_split_mode);
   mp3splt_set_int_option(the_state, SPLT_OPT_PRETEND_TO_SPLIT, SPLT_FALSE);
-
-  gdk_threads_enter();
+  mp3splt_set_split_filename_function(the_state,put_split_filename);
+ 
+  enter_threads();
 
   if (err >= 0)
   {
@@ -1095,41 +1213,135 @@ gpointer detect_silence_and_set_splitpoints(gpointer data)
 
   gtk_widget_set_sensitive(cancel_button, FALSE);
   gtk_widget_set_sensitive(GTK_WIDGET(scan_silence_button), TRUE);
+  gtk_widget_set_sensitive(GTK_WIDGET(scan_trim_silence_button), TRUE);
 
-  gdk_threads_leave();
+  exit_threads();
 
   return NULL;
 }
 
-//start thread with 'set splitpints from silence detection'
+//!start thread with 'set splitpints from silence detection'
 void detect_silence_and_add_splitpoints_start_thread()
 {
-  g_thread_create(detect_silence_and_set_splitpoints,
-                  NULL, TRUE, NULL);
+  create_thread(detect_silence_and_set_splitpoints, GINT_TO_POINTER(SPLT_FALSE), TRUE, NULL);
 }
 
-//update silence parameters when 'widget' changes
+void detect_silence_and_add_trim_splitpoints_start_thread()
+{
+  create_thread(detect_silence_and_set_splitpoints, GINT_TO_POINTER(SPLT_TRUE), TRUE, NULL);
+}
+
+//!update silence parameters when 'widget' changes
 void update_silence_parameters(GtkWidget *widget, gpointer data)
 {
   silence_threshold_value = 
-    gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(spinner_silence_threshold));
-  silence_offset_value =
-    gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(spinner_silence_offset));
-  silence_number_of_tracks =
-    gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spinner_silence_number_tracks));
-  silence_minimum_length = 
-    gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(spinner_silence_minimum));
-  silence_remove_silence_between_tracks = 
-    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(silence_remove_silence));
+    gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinner_silence_threshold));
+  if (spinner_silence_offset != NULL)
+  {
+    silence_offset_value =
+      gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinner_silence_offset));
+  }
+  if (spinner_silence_number_tracks != NULL)
+  {
+    silence_number_of_tracks =
+      gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spinner_silence_number_tracks));
+  }
+  if (spinner_silence_minimum != NULL)
+  {
+    silence_minimum_length = 
+      gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinner_silence_minimum));
+  }
+  if (spinner_silence_minimum_track != NULL)
+  {
+    silence_minimum_track_length = 
+      gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinner_silence_minimum_track));
+  }
+  if (silence_remove_silence != NULL)
+  {
+    silence_remove_silence_between_tracks = 
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(silence_remove_silence));
+  }
 }
 
-//action when checking the 'remove silence' button
+//!action when checking the 'remove silence' button
 void silence_remove_silence_checked(GtkToggleButton *button, gpointer data)
 {
   update_silence_parameters(GTK_WIDGET(button), data);
 }
 
-//event for clicking the 'detect silence and add splitpoints' button
+void create_trim_silence_window(GtkWidget *button, gpointer *data)
+{
+  GtkWidget *silence_detection_window =
+    gtk_dialog_new_with_buttons(_("Set trim splitpoints using silence detection"),
+        GTK_WINDOW(window),
+        GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
+        GTK_STOCK_OK,
+        GTK_RESPONSE_YES,
+        GTK_STOCK_CANCEL,
+        GTK_RESPONSE_CANCEL,
+        NULL);
+
+  gtk_widget_set_size_request(silence_detection_window, 300, 90);
+
+  GtkWidget *general_inside_vbox = gtk_vbox_new(FALSE, 0);
+  //add silence parameters
+  GtkWidget *horiz_fake = gtk_hbox_new(FALSE,0);
+  gtk_box_pack_start(GTK_BOX(general_inside_vbox), horiz_fake, FALSE, FALSE, 10);
+  
+  //vertical parameter box
+  GtkWidget *param_vbox;
+  param_vbox = gtk_vbox_new(FALSE,0);
+  gtk_box_pack_start(GTK_BOX(horiz_fake), param_vbox, FALSE, FALSE, 25);
+  
+  //horizontal box fake for threshold level
+  horiz_fake = gtk_hbox_new(FALSE,0);
+  gtk_box_pack_start(GTK_BOX(param_vbox), 
+      horiz_fake, FALSE, FALSE, 0);
+  
+  //threshold level
+  GtkWidget *label = gtk_label_new(_("Threshold level (dB):"));
+  gtk_box_pack_start(GTK_BOX(horiz_fake), label, FALSE, FALSE, 0);
+  
+  //adjustement for the threshold spinner
+  GtkAdjustment *adj = (GtkAdjustment *)
+    gtk_adjustment_new(0.0, -96.0, 0.0, 0.5, 10.0, 0.0);
+  //the threshold spinner
+  spinner_silence_threshold = gtk_spin_button_new(adj, 0.5, 2);
+  //set not editable
+  gtk_box_pack_start(GTK_BOX(horiz_fake), 
+      spinner_silence_threshold, FALSE, FALSE, 6);
+  
+  //we set the default parameters for the silence split
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinner_silence_threshold),
+      silence_threshold_value);
+
+  //add actions when changing the values
+  g_signal_connect(G_OBJECT(spinner_silence_threshold), "value_changed",
+      G_CALLBACK(update_silence_parameters), NULL);
+
+  gtk_widget_show_all(general_inside_vbox);
+  gtk_container_add(GTK_CONTAINER(
+        gtk_dialog_get_content_area(GTK_DIALOG(silence_detection_window))),
+      general_inside_vbox);
+
+  //result of the dialog window
+  gint result = gtk_dialog_run(GTK_DIALOG(silence_detection_window));
+
+  //we set the silence parameters
+  mp3splt_set_float_option(the_state, SPLT_OPT_PARAM_THRESHOLD,
+      silence_threshold_value);
+
+  mp3splt_set_int_option(the_state, SPLT_OPT_DEBUG_MODE, debug_is_active);
+
+  gtk_widget_destroy(silence_detection_window);
+
+  if (result == GTK_RESPONSE_YES)
+  {
+    detect_silence_and_add_trim_splitpoints_start_thread();
+  }
+}
+
+//!event for clicking the 'detect silence and add splitpoints' button
 void create_detect_silence_and_add_splitpoints_window(GtkWidget *button, gpointer *data)
 {
   GtkWidget *silence_detection_window =
@@ -1151,8 +1363,7 @@ void create_detect_silence_and_add_splitpoints_window(GtkWidget *button, gpointe
   //vertical parameter box
   GtkWidget *param_vbox;
   param_vbox = gtk_vbox_new(FALSE,0);
-  gtk_box_pack_start(GTK_BOX(horiz_fake), 
-                      param_vbox, FALSE, FALSE, 25);
+  gtk_box_pack_start(GTK_BOX(horiz_fake), param_vbox, FALSE, FALSE, 25);
   
   //horizontal box fake for threshold level
   horiz_fake = gtk_hbox_new(FALSE,0);
@@ -1219,6 +1430,18 @@ void create_detect_silence_and_add_splitpoints_window(GtkWidget *button, gpointe
   gtk_box_pack_start(GTK_BOX(horiz_fake), spinner_silence_minimum,
       FALSE, FALSE, 6);
   
+  //the minimum track length parameter
+  horiz_fake = gtk_hbox_new(FALSE,0);
+  gtk_box_pack_start(GTK_BOX(param_vbox), horiz_fake, FALSE, FALSE, 0);
+ 
+  label = gtk_label_new(_("Minimum track length (seconds):"));
+  gtk_box_pack_start(GTK_BOX(horiz_fake), label, FALSE, FALSE, 0);
+  
+  adj = (GtkAdjustment *)gtk_adjustment_new(0.0, 0, 2000, 0.5, 10.0, 0.0);
+  spinner_silence_minimum_track = gtk_spin_button_new(adj, 1, 2);
+  gtk_box_pack_start(GTK_BOX(horiz_fake), spinner_silence_minimum_track,
+      FALSE, FALSE, 6);
+ 
   //remove silence (rm): allows you to remove the silence between
   //tracks
   silence_remove_silence =
@@ -1235,6 +1458,8 @@ void create_detect_silence_and_add_splitpoints_window(GtkWidget *button, gpointe
                             silence_number_of_tracks);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinner_silence_minimum),
                             silence_minimum_length);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinner_silence_minimum_track),
+                            silence_minimum_track_length);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(silence_remove_silence),
       silence_remove_silence_between_tracks);
 
@@ -1247,11 +1472,14 @@ void create_detect_silence_and_add_splitpoints_window(GtkWidget *button, gpointe
       G_CALLBACK(update_silence_parameters), NULL);
   g_signal_connect(G_OBJECT(spinner_silence_minimum), "value_changed",
       G_CALLBACK(update_silence_parameters), NULL);
+  g_signal_connect(G_OBJECT(spinner_silence_minimum_track), "value_changed",
+      G_CALLBACK(update_silence_parameters), NULL);
   g_signal_connect(G_OBJECT(silence_remove_silence), "toggled",
       G_CALLBACK(silence_remove_silence_checked), NULL);
 
   gtk_widget_show_all(general_inside_vbox);
-  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(silence_detection_window)->vbox),
+  gtk_container_add(GTK_CONTAINER(
+        gtk_dialog_get_content_area(GTK_DIALOG(silence_detection_window))),
       general_inside_vbox);
 
   //result of the dialog window
@@ -1266,6 +1494,8 @@ void create_detect_silence_and_add_splitpoints_window(GtkWidget *button, gpointe
       silence_number_of_tracks);
   mp3splt_set_float_option(the_state, SPLT_OPT_PARAM_MIN_LENGTH,
       silence_minimum_length);
+  mp3splt_set_float_option(the_state, SPLT_OPT_PARAM_MIN_TRACK_LENGTH,
+      silence_minimum_track_length);
   mp3splt_set_int_option(the_state, SPLT_OPT_PARAM_REMOVE_SILENCE,
       silence_remove_silence_between_tracks);
 
@@ -1277,12 +1507,9 @@ void create_detect_silence_and_add_splitpoints_window(GtkWidget *button, gpointe
   {
     detect_silence_and_add_splitpoints_start_thread();
   }
-  else if (result == GTK_RESPONSE_CANCEL)
-  {
-  }
 }
 
-//remove a row from the table
+//!remove a row from the table
 void remove_row(GtkWidget *widget, gpointer data)
 {
   GtkTreeSelection *selection;
@@ -1327,7 +1554,7 @@ void remove_row(GtkWidget *widget, gpointer data)
   g_list_free (selected_list);
 }
 
-//removes all rows from the table
+//!removes all rows from the table
 void remove_all_rows (GtkWidget *widget, gpointer data)
 {
   GtkTreeIter iter;
@@ -1346,11 +1573,11 @@ void remove_all_rows (GtkWidget *widget, gpointer data)
   }
   
   //disable remove all button
-  if(GTK_WIDGET_SENSITIVE(remove_all_button))
+  if(gtk_widget_get_sensitive(remove_all_button))
     gtk_widget_set_sensitive(GTK_WIDGET(remove_all_button), FALSE);
   
   //disable remove button
-  if(GTK_WIDGET_SENSITIVE(remove_row_button))
+  if(gtk_widget_get_sensitive(remove_row_button))
     gtk_widget_set_sensitive(GTK_WIDGET(remove_row_button), FALSE);
   
   remove_status_message();
@@ -1361,7 +1588,7 @@ void remove_all_rows (GtkWidget *widget, gpointer data)
   check_update_down_progress_bar();
 }
 
-//creates and and initialise a spinner
+//!creates and and initialise a spinner
 GtkWidget *create_init_spinner(GtkWidget *bottomhbox1, 
                                gint min, gint max, 
                                gchar *label_text,
@@ -1412,7 +1639,7 @@ GtkWidget *create_init_spinner(GtkWidget *bottomhbox1,
   return spinner;
 }
 
-//minutes ,seconds spinners ; add, delete buttons
+//!minutes ,seconds spinners ; add, delete buttons
 GtkWidget *create_init_spinners_buttons(GtkTreeView *tree_view)
 {
   GtkWidget *hbox;
@@ -1471,7 +1698,7 @@ GtkWidget *create_init_spinners_buttons(GtkTreeView *tree_view)
   return hbox;
 }
 
-//special buttons like 'set silence from silence detection'
+//!special buttons like 'set silence from silence detection'
 GtkWidget *create_init_special_buttons(GtkTreeView *tree_view)
 {
   GtkWidget *hbox;
@@ -1480,8 +1707,8 @@ GtkWidget *create_init_special_buttons(GtkTreeView *tree_view)
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 0);
 
   /* set splitpoints from silence detection */
-  scan_silence_button = (GtkWidget *)create_cool_button(GTK_STOCK_ADD,
-                                               _("_Silence detection"), FALSE);
+  scan_silence_button =
+    (GtkWidget *)create_cool_button(GTK_STOCK_ADD, _("_Silence detection"), FALSE);
   gtk_widget_set_sensitive(GTK_WIDGET(scan_silence_button), TRUE);
   g_signal_connect(G_OBJECT(scan_silence_button), "clicked",
       G_CALLBACK(create_detect_silence_and_add_splitpoints_window), NULL);
@@ -1489,18 +1716,30 @@ GtkWidget *create_init_special_buttons(GtkTreeView *tree_view)
   gtk_widget_set_tooltip_text(scan_silence_button,
       _("Set splitpoints from silence detection"));
 
+  /* set splitpoints from trim silence detection */
+  scan_trim_silence_button =
+    (GtkWidget *)create_cool_button(GTK_STOCK_CUT, _("_Trim splitpoints"), FALSE);
+  gtk_widget_set_sensitive(GTK_WIDGET(scan_trim_silence_button), TRUE);
+  g_signal_connect(G_OBJECT(scan_trim_silence_button), "clicked",
+      G_CALLBACK(create_trim_silence_window), NULL);
+  gtk_box_pack_end(GTK_BOX(hbox), scan_trim_silence_button, FALSE, FALSE, 5);
+  gtk_widget_set_tooltip_text(scan_trim_silence_button,
+      _("Set trim splitpoints using silence detection"));
+
   return hbox;
 }
 
-//returns the hundreths of seconds from a Split_point
+//!returns the hundreths of seconds from a Split_point
 gint splitpoint_to_hundreths(Split_point point)
 {
   return (point.secs + point.mins*60)*1000+
     point.hundr_secs * 10;
 }
 
-//returns the name of the splitpoint
-//result must be freed
+/*! returns the name of the splitpoint
+
+result must be g_free'd after use
+*/
 gchar *get_splitpoint_name(gint index)
 {
   GtkTreeModel *model;
@@ -1531,7 +1770,7 @@ gchar *get_splitpoint_name(gint index)
   return description;
 }
 
-//returns a splitpoint from the table
+//!returns a splitpoint from the table
 gint get_splitpoint_time(gint this_splitpoint)
 {
   if (this_splitpoint != -1)
@@ -1566,7 +1805,7 @@ gpointer split_preview(gpointer data)
     mp3splt_set_int_option(the_state, SPLT_OPT_SPLIT_MODE,
         SPLT_OPTION_NORMAL_MODE);
 
-    gdk_threads_enter();
+    enter_threads();
 
     put_options_from_preferences();
 
@@ -1576,15 +1815,15 @@ gpointer split_preview(gpointer data)
     fname_path[strlen(fname_path)-18] = '\0';
 
     remove_all_split_rows();  
-    filename_to_split = (gchar *)gtk_entry_get_text(GTK_ENTRY(entry));
+    filename_to_split = inputfilename_get();
 
-    gdk_threads_leave();
+    exit_threads();
 
     mp3splt_set_path_of_split(the_state,fname_path);
     mp3splt_set_filename_to_split(the_state,filename_to_split);
     confirmation = mp3splt_split(the_state);
 
-    gdk_threads_enter();
+    enter_threads();
 
     print_status_bar_confirmation(confirmation);
 
@@ -1618,27 +1857,24 @@ gpointer split_preview(gpointer data)
       fname_path = NULL;
     }
 
-    gdk_threads_leave();
+    exit_threads();
   }
   else
   {
-    gdk_threads_enter();
+    enter_threads();
 
     put_status_message(_(" cannot split preview last splitpoint"));
 
-    gdk_threads_leave();
+    exit_threads();
   }
 
   return NULL;
 }
 
-//the row clicked event, preview the song
+//!the row clicked event, preview the song
 void preview_song(GtkTreeView *tree_view, GtkTreePath *path,
     GtkTreeViewColumn *col, gpointer user_data)
 {
-  GtkTreeModel *model;
-  model = gtk_tree_view_get_model(tree_view);
-  
   gint number = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(col), "col"));
 
   //only when clicking on the PREVIEW or SPLIT_PREVIEW columns
@@ -1662,7 +1898,7 @@ void preview_song(GtkTreeView *tree_view, GtkTreePath *path,
         {
           preview_start_position = get_splitpoint_time(this_row);
           quick_preview_end_splitpoint = this_row+1;
-          g_thread_create(split_preview, NULL, TRUE, NULL);
+          create_thread(split_preview, NULL, TRUE, NULL);
         }
       }
     }
@@ -1673,7 +1909,7 @@ void preview_song(GtkTreeView *tree_view, GtkTreePath *path,
   }
 }
 
-//toggle 'check' button
+//!toggle 'check' button
 static void toggled_splitpoint_event(GtkCellRendererToggle *cell,
     gchar *path_str, gpointer data)
 {
@@ -1707,7 +1943,7 @@ static void toggled_splitpoint_event(GtkCellRendererToggle *cell,
   gtk_tree_path_free(path);
 }
 
-//creates columns for the tree
+//!creates columns for the tree
 void create_columns (GtkTreeView *tree_view)
 {
   //cells renderer
@@ -1887,7 +2123,7 @@ void create_columns (GtkTreeView *tree_view)
   gtk_tree_view_column_set_expand (column_description, TRUE);
 }
 
-//when closing the new window after detaching
+//!Issued when closing the new window after detaching
 void close_popup_window_event( GtkWidget *window,
                                gpointer data )
 {
@@ -1900,7 +2136,7 @@ void close_popup_window_event( GtkWidget *window,
   gtk_widget_destroy(window);
 }
 
-//when we detach the handle
+//!Issued when we detach the handle
 void handle_detached_event (GtkHandleBox *handlebox,
                             GtkWidget *widget,
                             gpointer data)
@@ -1920,8 +2156,11 @@ void handle_detached_event (GtkHandleBox *handlebox,
   gtk_widget_show(GTK_WIDGET(window));
 }
 
-//creates the choose splitpoints frame, who has the spinners, arrows,
-//the tree, add, remove buttons
+/*!creates the choose splitpoints frame
+
+This frame contains the spinners, arrows, the tree, add, remove
+buttons
+*/
 GtkWidget *create_choose_splitpoints_frame(GtkTreeView *tree_view)
 {
   //choose splitpoints box, has tree, spinner, arrows..
@@ -2001,7 +2240,7 @@ static void garray_to_array(GArray *spltpoints, glong *hundredth)
     }
 }
 
-//puts the splitpoints in the state
+//!puts the splitpoints into the state
 void put_splitpoints_in_the_state(splt_state *state)
 {
   glong hundr[splitnumber];
@@ -2035,16 +2274,16 @@ void put_splitpoints_in_the_state(splt_state *state)
         splitpoint_type = SPLT_SKIPPOINT;
       }
 
-      gdk_threads_leave();
+      exit_threads();
       mp3splt_append_splitpoint(state,hundr[i], description, splitpoint_type);
-      gdk_threads_enter();
+      enter_threads();
        
       //free memory
       gtk_tree_path_free(path);
     }
 }
 
-//creates the tree view
+//!creates the tree view
 GtkTreeView *create_tree_view()
 {
   GtkTreeModel *model;
