@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2010 Alexandru Munteanu
+ * Copyright: (C) 2005-2011 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -29,6 +29,14 @@
  *
  *********************************************************/
 
+/*!********************************************************
+ * \file
+ *  miscellaneous utilities
+ *
+ * Miscellaneous utilities like the check if a string may 
+ * contain a valid file- or directory name.
+ ********************************************************/
+
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <string.h>
@@ -41,7 +49,7 @@
 #include "preferences_tab.h"
 #include "main_win.h"
 
-//check if its a file
+//!check if the string passed as an argument points to a file
 gint is_filee(const gchar *fname)
 {
   if (fname == NULL)
@@ -71,14 +79,16 @@ gint is_filee(const gchar *fname)
   }
 }
 
-//check if its a directory
-//TODO: why guchar ?
+/*!check if a string points to a directory
+
+\todo why guchar?
+*/
 gint check_if_dir(guchar *fname)
 {
   struct stat buffer;
-  gint         status;
-  
-  status = g_stat((gchar *)fname, &buffer);
+
+  g_stat((gchar *)fname, &buffer);
+
   //if it is a directory
   if (S_ISDIR(buffer.st_mode) != 0)
     return TRUE;
@@ -86,14 +96,17 @@ gint check_if_dir(guchar *fname)
     return FALSE;
 }
 
-//check if its a file
-//TODO: why guchar ?
+/*! check if a sting points to a file
+
+\todo
+ - Why guchar ?
+ - And what is the difference to is_filee?
+*/
 gint check_if_file(guchar *fname)
 {
   struct stat buffer;
-  gint         status;
 
-  status = g_stat((gchar *)fname, &buffer);
+  g_stat((gchar *)fname, &buffer);
   //if it is a file
   if (S_ISREG(buffer.st_mode) != 0)
     return TRUE;
@@ -101,25 +114,10 @@ gint check_if_file(guchar *fname)
     return FALSE;
 }
 
-GtkWidget *set_title_and_get_vbox(GtkWidget *widget, gchar *title)
-{
-  GtkWidget *label = gtk_label_new(NULL);
-  gtk_label_set_markup(GTK_LABEL(label), title);
-
-  GtkWidget *label_hbox = gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(label_hbox), label, FALSE, FALSE, 0);
-
-  GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(vbox), label_hbox, FALSE, FALSE, 5);
-
-  GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(hbox), widget, TRUE, TRUE, 16);
-
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-
-  return vbox;
-}
+/*! Issues the message "Processing file <filename>" into the message bar
 
+\param filename The filename that has to be printed.
+ */
 void print_processing_file(gchar *filename)
 {
   gint fname_status_size = (strlen(filename) + 255);
@@ -134,6 +132,12 @@ void print_processing_file(gchar *filename)
   }
 }
 
+/*! Does this GtkContainer contain that object?
+
+\param GtkContainer The Container that has to be searched for the
+child object.
+\param my_child The child that has to be searched for.
+ */
 gboolean container_has_child(GtkContainer *container, GtkWidget *my_child)
 {
   GList *children = gtk_container_get_children(GTK_CONTAINER(container));
@@ -150,7 +154,11 @@ gboolean container_has_child(GtkContainer *container, GtkWidget *my_child)
 
   return FALSE;
 }
+/*! Removes trailing \\r or \\n characters from a filename
 
+\todo Cannot find any code that removes a trailing slash as this
+function would suggest
+ */
 void remove_end_slash_n_r_from_filename(char *filename)
 {
   if (filename == NULL)
@@ -175,11 +183,16 @@ void remove_end_slash_n_r_from_filename(char *filename)
   }
 }
 
-//transform text to utf8
-//free_or_not:  TRUE if we free text before and 
-//otherwise FALSE
-//the third result returns us if the result must be freed 
-//or not
+/*! transform text to utf8
+
+\param text The text thet has to be converted
+\param free_or_not: TRUE if this function has to g_free() the text if
+during conversion it has to copy the text to a new (e.G. larger) buffer.
+\param must_be_freed reads true, if this function has allocated a new
+chunk of memory to have somewhere to put the output string in - which
+means that the memory the output string is in has to be freed after usage. 
+\return 
+*/
 gchar *transform_to_utf8(gchar *text, gint free_or_not,
     gint *must_be_freed)
 {
